/**************************************************************************//**
 * @file        FlashDef.h
 * @version     V1.0
 * $Revision:   0 $
 * $Date:       $
 * @brief       Flash struct typedef 
 *
 * @note
 * Copyright (C) 2016 AMICCOM Electronics Corp. All rights reserved.
 ******************************************************************************/
#ifndef __FLASHDEF_H__
#define __FLASHDEF_H__

/** @addtogroup FLASH
    memory mapped structure for FLASH
    @{
*/
typedef struct
{
    __IO    uint32_t  reserved1;          // Offset: 0x000
    __IO    uint32_t  CTRL;               // Offset: 0x004
    __IO    uint32_t  LENGTH;             // Offset: 0x008
    __IO    uint32_t  ADDR;               // Offset: 0x00C
    __IO    uint32_t  PWD0;               // Offset: 0x010
    __IO    uint32_t  PWD1;               // Offset: 0x014
    __IO    uint32_t  KEY0;               // Offset: 0x018
    __IO    uint32_t  KEY1;               // Offset: 0x01C
            uint8_t   reserved2[0x100-0x01C-4];
    union {
        __IO    uint32_t  DATA32[32];     // Offset: 0x100~0x17F
        __IO    uint8_t   DATA8[128];     // Offset: 0x100~0x17C
    };
            uint8_t   reserved3[0x200-0x180];
    __IO    uint32_t  LOCK[2];            // Offset: 0x200
} Flash_Type;

/* FLASH Register Definitions */

#define FLASH_CTRL_WRITE_Pos    0
#define FLASH_CTRL_WRITE_Msk    (0x1ul<<FLASH_CTRL_WRITE_Pos)
#define FLASH_CTRL_PROG_Pos     1
#define FLASH_CTRL_PROG_Msk     (0x1ul<<FLASH_CTRL_PROG_Pos)
#define FLASH_CTRL_PERASE_Pos   2
#define FLASH_CTRL_PERASE_Msk   (0x1ul<<FLASH_CTRL_PERASE_Pos)
#define FLASH_CTRL_SERASE_Pos   3
#define FLASH_CTRL_SERASE_Msk   (0x1ul<<FLASH_CTRL_SERASE_Pos)
#define FLASH_CTRL_MERASE_Pos   4
#define FLASH_CTRL_MERASE_Msk   (0x1ul<<FLASH_CTRL_MERASE_Pos)
#define FLASH_CTRL_F1M_Pos      5
#define FLASH_CTRL_F1M_Msk      (0x1ul<<FLASH_CTRL_F1M_Pos)
#define FLASH_CTRL_F2M_Pos      6
#define FLASH_CTRL_F2M_Msk      (0x1ul<<FLASH_CTRL_F2M_Pos)
#define FLASH_CTRL_CE_Pos       7
#define FLASH_CTRL_CE_Msk       (0x1ul<<FLASH_CTRL_CE_Pos)

#define FLASH_LENGTH_PWE_Pos    7
#define FLASH_LENGTH_PWE_Msk    (0x1ul<<FLASH_LENGTH_PWE_Pos)

/*@}*/ /* end of group UART */

/******************************************************************************/
/*                         Peripheral memory map                              */
/******************************************************************************/
/** @addtogroup PERIPHERAL_MEM_MAP Peripheral Memory Map
    @{
*/
#define FLASH_BASE              0x4001F100
/*@}*/ /* end of group PERIPHERAL_MEM_MAP */

/******************************************************************************/
/*                         Peripheral Definitions                             */
/******************************************************************************/
/** @addtogroup PERIPHERAL Peripheral Definitions
    @{
*/
#define FLASH                   ((Flash_Type *) FLASH_BASE)
/*@}*/ /* end of group PERIPHERAL */

#endif
