/*--------------------------------------------------------------------------*/
/*  register_A8137M0.H                                                      */
/****************************************************************************/
/*  Change Log:                                                             */
/*  Version: 0.0                                                            */
/*  Date   : 2018-01-05                                                     */
/*  Issue  : Creat A8137M0-U01                                              */
/*  Author : Achou                                                          */
/****************************************************************************/
/* Header file for A8137M0 RF SoC microcontroller.                          */
/* Copyright (c) 2018 AMICCOM Electronics Corp.                             */
/* All rights reserved.                                                     */
/*--------------------------------------------------------------------------*/

#ifndef _REGISTER_A8137M0_H_
#define _REGISTER_A8137M0_H_

/*
 * ==========================================================================
 * ---------- Global Definition -----------------------------------
 * ==========================================================================
 */

#define   __RO          volatile        const       /*!< Defines 'read only' permissions     */
#define   __WO          volatile                    /*!< Defines 'write only' permissions    */
#define   __RW          volatile                    /*!< Defines 'read / write' permissions  */

/* Variable type definition */
#define     Sint8       int8_t
#define     Sint16      int16_t
#define     Sint32      int32_t
#define     Uint8       uint8_t
#define     Uint16      uint16_t
#define     Uint32      uint32_t

#define     Sint8_      volatile int8_t
#define     Sint16_     volatile int16_t
#define     Sint32_     volatile int32_t
#define     Uint8_      volatile uint8_t
#define     Uint16_     volatile uint16_t
#define     Uint32_     volatile uint32_t
    
/* Bit Mask Definitions */
#define BIT0    0x00000001
#define BIT1    0x00000002
#define BIT2    0x00000004
#define BIT3    0x00000008
#define BIT4    0x00000010
#define BIT5    0x00000020
#define BIT6    0x00000040
#define BIT7    0x00000080
#define BIT8    0x00000100
#define BIT9    0x00000200
#define BIT10   0x00000400
#define BIT11   0x00000800
#define BIT12   0x00001000
#define BIT13   0x00002000
#define BIT14   0x00004000
#define BIT15   0x00008000
#define BIT16   0x00010000
#define BIT17   0x00020000
#define BIT18   0x00040000
#define BIT19   0x00080000
#define BIT20   0x00100000
#define BIT21   0x00200000
#define BIT22   0x00400000
#define BIT23   0x00800000
#define BIT24   0x01000000
#define BIT25   0x02000000
#define BIT26   0x04000000
#define BIT27   0x08000000
#define BIT28   0x10000000
#define BIT29   0x20000000
#define BIT30   0x40000000
#define BIT31   0x80000000

/* Basic Definitions */
#define PASS    (0)
#define FAIL    (~PASS)

#define DISABLE (0)
#define ENABLE  (~DISABLE)

#define MASTER  (BIT0)
#define SLAVE   (BIT1)

/* Extract Address value Definitions */
typedef volatile unsigned char  REG8;
typedef volatile unsigned short REG16;
typedef volatile unsigned long  REG32;

#define HW8_REG(ADDRESS)  (*((REG8  *) (ADDRESS)))
#define HW16_REG(ADDRESS) (*((REG16 *) (ADDRESS)))
#define HW32_REG(ADDRESS) (*((REG32 *) (ADDRESS)))

/*  Strobe Command Definition */
#define CMD_SLEEP                       0x80    // SLEEP mode
#define CMD_IDLE                        0x90    // IDLE mode
#define CMD_STBY                        0xA0    // Standby mode
#define CMD_PLL                         0xB0    // PLL mode
#define CMD_RX                          0xC0    // RX mode
#define CMD_TX                          0xD0    // TX mode

/*  Reset Command Definition */
#define RF_RST                          0x80
#define TXFIFOPOINT_RST                 0x40
#define RXFIFOPOINT_RST                 0x20
#define FIFODATA_RST                    0x10
#define BFC_RST                         0x08

/*
 * ==========================================================================
 * ---------- Interrupt Number Definition -----------------------------------
 * ==========================================================================
 */

typedef enum IRQn
{
    /******  Cortex-M0 Processor Exceptions Numbers *************************************************/

    /* ToDo: use this Cortex interrupt numbers if your device is a CORTEX-M0 device                 */
    NonMaskableInt_IRQn           = -14,    /*!<  2 Cortex-M0 Non Maskable Interrupt                */
    HardFault_IRQn                = -13,    /*!<  3 Cortex-M0 Hard Fault Interrupt                  */
    SVCall_IRQn                   = -5,     /*!< 11 Cortex-M0 SV Call Interrupt                     */
    PendSV_IRQn                   = -2,     /*!< 14 Cortex-M0 Pend SV Interrupt                     */
    SysTick_IRQn                  = -1,     /*!< 15 Cortex-M0 System Tick Interrupt                 */

    /******  AMICCOM A8137M0 Specific Interrupt Numbers *********************************************/
    UART0_IRQn                    = 1,      /*!< UART0 Tx/Rx/Overflow interrupt                     */
    RADIO_IRQn                    = 3,      /*!< RADIO Interrupt                                    */
    UART2_IRQn                    = 5,      /*!< UART2 Tx/Rx/Overflow interrupt                     */
    PORT0_COMB_IRQn               = 6,      /*!< GPIO 0 combined/Key interrupt Interrupt            */
    TIMER0_IRQn                   = 8,      /*!< TIMER 0 Interrupt                                  */
    TIMER1_IRQn                   = 9,      /*!< TIMER 1 Interrupt                                  */
    DUALTIMER_IRQn                = 10,     /*!< Dual Timer Interrupt                               */
    CHARGE_IRQn                   = 11,     /*!< CHARGE Interrupt                                   */
    UART1_IRQn                    = 13,     /*!< UART1 Tx/Rx/Overflow interrupt                     */
    SPI_IRQn                      = 16,     /*!< SPI Interrupt                                      */
    I2C_IRQn                      = 17,     /*!< I2C Interrupt                                      */
    ADC_12BIT_IRQn                = 21,     /*!< 12-BIT ADC Interrupt                               */
} IRQn_Type;

/*
 * ==========================================================================
 * ----------- Processor and Core Peripheral Section ------------------------
 * ==========================================================================
 */

/* Configuration of the Cortex-M0 Processor and Core Peripherals */
#define __CM0_REV                 0x0000    /*!< Core Revision r0p0                            */
#define __NVIC_PRIO_BITS          2         /*!< Number of Bits used for Priority Levels       */
#define __Vendor_SysTickConfig    0         /*!< Set to 1 if different SysTick Config is used  */
#define __MPU_PRESENT             0         /*!< MPU present or not                            */

#include "core_cm0.h"                       /* !< Cortex-M0 processor and core peripherals  */
#include "system_A8137M0.h"                 /* !< A8137M0 System                            */

#if defined ( __CC_ARM   )
#pragma anon_unions
#endif

/******************************************************************************/
/*                Device Specific Peripheral registers structures             */
/******************************************************************************/

/*----------------------------- Timer Controller(TIMER) -------------------------------*/
/** @addtogroup TIMER
    memory mapped structure for Timer
    @{
*/

typedef struct
{
        __RW    uint32_t    CTRL;       /* !< Offset: 0x000 Control Register           */
        __RW    uint32_t    VALUE;      /* !< Offset: 0x004 Current Value Register     */
        __RW    uint32_t    RELOAD;     /* !< Offset: 0x008 Reload Value Register      */
        union {                         /*                                             */
        __RO    uint32_t    INTSTATUS;  /* !< Offset: 0x00C Interrupt Status Register  */
        __WO    uint32_t    INTCLEAR;   /* !< Offset: 0x00C Interrupt Clear Register   */
        };

} TIMER_Type;

/* TIMER CTRL Register Definitions */

#define TIMER_CTRL_IRQEN_Pos        3                                           /*!< TIMER CTRL: IRQEN Position         */
#define TIMER_CTRL_IRQEN_Msk        (0x01ul << TIMER_CTRL_IRQEN_Pos)            /*!< TIMER CTRL: IRQEN Mask             */
                                                                                /*                                      */
#define TIMER_CTRL_SELEXTCLK_Pos    2                                           /*!< TIMER CTRL: SELEXTCLK Position     */
#define TIMER_CTRL_SELEXTCLK_Msk    (0x01ul << TIMER_CTRL_SELEXTCLK_Pos)        /*!< TIMER CTRL: SELEXTCLK Mask         */
                                                                                /*                                      */
#define TIMER_CTRL_SELEXTEN_Pos     1                                           /*!< TIMER CTRL: SELEXTEN Position      */
#define TIMER_CTRL_SELEXTEN_Msk     (0x01ul << TIMER_CTRL_SELEXTEN_Pos)         /*!< TIMER CTRL: SELEXTEN Mask          */
                                                                                /*                                      */
#define TIMER_CTRL_EN_Pos           0                                           /*!< TIMER CTRL: EN Position            */
#define TIMER_CTRL_EN_Msk           (0x01ul << TIMER_CTRL_EN_Pos)               /*!< TIMER CTRL: EN Mask                */
                                                                                /*                                      */
#define TIMER_VAL_CURRENT_Pos       0                                           /*!< TIMER VALUE: CURRENT Position      */
#define TIMER_VAL_CURRENT_Msk       (0xFFFFFFFFul << TIMER_VAL_CURRENT_Pos)     /*!< TIMER VALUE: CURRENT Mask          */
                                                                                /*                                      */
#define TIMER_RELOAD_VAL_Pos        0                                           /*!< TIMER RELOAD: RELOAD Position      */
#define TIMER_RELOAD_VAL_Msk        (0xFFFFFFFFul << TIMER_RELOAD_VAL_Pos)      /*!< TIMER RELOAD: RELOAD Mask          */
                                                                                /*                                      */
#define TIMER_INTSTATUS_Pos         0                                           /*!< TIMER INTSTATUS: INTSTATUSPosition */
#define TIMER_INTSTATUS_Msk         (0x01ul << TIMER_INTSTATUS_Pos)             /*!< TIMER INTSTATUS: INTSTATUSMask     */
                                                                                /*                                      */
#define TIMER_INTCLEAR_Pos          0                                           /*!< TIMER INTCLEAR: INTCLEAR Position  */
#define TIMER_INTCLEAR_Msk          (0x01ul << TIMER_INTCLEAR_Pos)              /*!< TIMER INTCLEAR: INTCLEAR Mask      */
                                    
#define Timer_TimerMode             ( TIMER_CTRL_EN_Msk                            )
#define Timer_CounterMode           ( Timer_TimerMode   + TIMER_CTRL_SELEXTCLK_Msk )
#define Timer_SwitchMode            ( Timer_TimerMode   + TIMER_CTRL_SELEXTEN_Msk  )
#define Timer_TiemrMode_IRQ         ( Timer_TimerMode   + TIMER_CTRL_IRQEN_Msk     )
#define Tiemr_CounterMode_IRQ       ( Timer_CounterMode + TIMER_CTRL_IRQEN_Msk     )
#define Timer_SwitchMode_IRQ        ( Timer_SwitchMode  + TIMER_CTRL_IRQEN_Msk     )

/*@}*/ /* end of group TIMER */

/*----------------------------- Dual Timer Controller (DualTIMER) -------------------------------*/
/** @addtogroup DualTIMER Dual Timer
    memory mapped structure for DualTIMER Dual Timer
    @{
*/

typedef struct
{
  __RW uint32_t LOAD;           /* !< Timer Load </h>                       */
  __RO  uint32_t VALUE;         /* !< Timer Counter Current Value <r></h>   */
  __RW uint32_t CTRL;           /* !< Timer Control                         */
                                /*   <o.7> TimerEn: Timer Enable            */
                                /*   <o.6> TimerMode: Timer Mode            */
                                /*     <0=> Freerunning-mode                */
                                /*     <1=> Periodic mode                   */
                                /*   <o.5> IntEnable: Interrupt Enable      */
                                /*   <o.2..3> TimerPre: Timer Prescale      */
                                /*     <0=> / 1                             */
                                /*     <1=> / 16                            */
                                /*     <2=> / 256                           */
                                /*     <3=> Undefined!                      */
                                /*   <o.1> TimerSize: Timer Size            */
                                /*     <0=> 16-bit counter                  */
                                /*     <1=> 32-bit counter                  */
                                /*   <o.0> OneShot: One-shoot mode          */
                                /*     <0=> Wrapping mode                   */
                                /*     <1=> One-shot mode                   */
  __WO  uint32_t INTCLEAR;      /* !< Timer Interrupt Clear                 */
  __RO  uint32_t RIS;           /* !< Timer Raw Interrupt Status            */
  __RO  uint32_t MIS;           /* !< Timer Masked Interrupt Status         */
  __RW uint32_t BGLOAD;         /* !< Background Load Register              */
} DUALTIMER_Type;                                         

/* DualTIMER CTRL Register Definitions */

#define DualTIMER_LOAD_Pos              0                                           /*!< DualTIMER LOAD: LOAD Position                   */
#define DualTIMER_LOAD_Msk              (0xFFFFFFFFul << DualTIMER_LOAD_Pos)        /*!< DualTIMER LOAD: LOAD Mask                       */
                                                                                    /*                                                   */
#define DualTIMER_VALUE_Pos             0                                           /*!< DualTIMER VALUE: VALUE Position                 */
#define DualTIMER_VALUE_Msk             (0xFFFFFFFFul << DualTIMER_VALUE_Pos)       /*!< DualTIMER VALUE: VALUE Mask                     */
                                                                                    /*                                                   */
#define DualTIMER_CTRL_EN_Pos           7                                           /*!< DualTIMER CTRL_EN: CTRL Enable Position         */
#define DualTIMER_CTRL_EN_Msk           (0x1ul << DualTIMER_CTRL_EN_Pos)            /*!< DualTIMER CTRL_EN: CTRL Enable Mask             */
                                                                                    /*                                                   */
#define DualTIMER_CTRL_MODE_Pos         6                                           /*!< DualTIMER CTRL_MODE: CTRL MODE Position         */
#define DualTIMER_CTRL_MODE_Msk         (0x1ul << DualTIMER_CTRL_MODE_Pos)          /*!< DualTIMER CTRL_MODE: CTRL MODE Mask             */
                                                                                    /*                                                   */
#define DualTIMER_CTRL_INTEN_Pos        5                                           /*!< DualTIMER CTRL_INTEN: CTRL Int Enable Position  */
#define DualTIMER_CTRL_INTEN_Msk        (0x1ul << DualTIMER_CTRL_INTEN_Pos)         /*!< DualTIMER CTRL_INTEN: CTRL Int Enable Mask      */
                                                                                    /*                                                   */
#define DualTIMER_CTRL_PRESCALE_Pos     2                                           /*!< DualTIMER CTRL_PRESCALE: CTRL PRESCALE Position */
#define DualTIMER_CTRL_PRESCALE_Msk     (0x3ul << DualTIMER_CTRL_PRESCALE_Pos)      /*!< DualTIMER CTRL_PRESCALE: CTRL PRESCALE Mask     */
                                                                                    /*                                                   */
#define DualTIMER_CTRL_SIZE_Pos         1                                           /*!< DualTIMER CTRL_SIZE: CTRL SIZE Position         */
#define DualTIMER_CTRL_SIZE_Msk         (0x1ul << DualTIMER_CTRL_SIZE_Pos)          /*!< DualTIMER CTRL_SIZE: CTRL SIZE Mask             */
                                                                                    /*                                                   */
#define DualTIMER_CTRL_ONESHOOT_Pos     0                                           /*!< DualTIMER CTRL_ONESHOOT: CTRL ONESHOOT Position */
#define DualTIMER_CTRL_ONESHOOT_Msk     (0x1ul << DualTIMER_CTRL_ONESHOOT_Pos)      /*!< DualTIMER CTRL_ONESHOOT: CTRL ONESHOOT Mask     */
                                                                                    /*                                                   */
#define DualTIMER_INTCLR_Pos            0                                           /*!< DualTIMER INTCLR: INT Clear Position            */
#define DualTIMER_INTCLR_Msk            (0x1ul << DualTIMER_INTCLR_Pos)             /*!< DualTIMER INTCLR: INT Clear  Mask               */
                                                                                    /*                                                   */
#define DualTIMER_RAWINTSTAT_Pos        0                                           /*!< DualTIMER RAWINTSTAT: Raw Int Status Position   */
#define DualTIMER_RAWINTSTAT_Msk        (0x1ul << DualTIMER_RAWINTSTAT_Pos)         /*!< DualTIMER RAWINTSTAT: Raw Int Status Mask       */
                                                                                    /*                                                   */
#define DualTIMER_MASKINTSTAT_Pos       0                                           /*!< DualTIMER MASKINTSTAT: Mask Int Status Position */
#define DualTIMER_MASKINTSTAT_Msk       (0x1ul << DualTIMER_MASKINTSTAT_Pos)        /*!< DualTIMER MASKINTSTAT: Mask Int Status Mask     */
                                                                                    /*                                                   */
#define DualTIMER_BGLOAD_Pos            0                                           /*!< DualTIMER BGLOAD: Background Load Position      */
#define DualTIMER_BGLOAD_Msk            (0xFFFFFFFFul << DualTIMER_BGLOAD_Pos)      /*!< DualTIMER BGLOAD: Background Load Mask          */

#define DualTimer_FreeRun_Waring           ( DUALTIMER_CTRL_EN_Msk                                    ) 
#define DualTimer_Periodic_Waring          ( DUALTIMER_CTRL_EN_Msk      + DUALTIMER_CTRL_MODE_Msk     )
#define DualTimer_FreeRun_OneShot          ( DualTimer_FreeRun_Waring   + DUALTIMER_CTRL_ONESHOOT_Msk )
#define DualTimer_Periodic_OneShot         ( DualTimer_FreeRun_Waring   + DUALTIMER_CTRL_ONESHOOT_Msk )
#define DualTimer_FreeRun_Waring_IRQ       ( DualTimer_FreeRun_Waring   + DUALTIMER_CTRL_INTEN_Msk    )
#define DualTimer_Periodic_Waring_IRQ      ( DualTimer_Periodic_Waring  + DUALTIMER_CTRL_INTEN_Msk    )
#define DualTimer_FreeRun_OneShot_IRQ      ( DualTimer_FreeRun_OneShot  + DUALTIMER_CTRL_INTEN_Msk    )
#define DualTimer_Periodic_OneShot_IRQ     ( DualTimer_Periodic_OneShot + DUALTIMER_CTRL_INTEN_Msk    )

#define DualTimer_16BitCount               0x00
#define DualTimer_32BitCount               DUALTIMER_CTRL_SIZE_Msk

#define DualTimer_CLK_divided1             0x00
#define DualTimer_CLK_divided16            0x04
#define DualTimer_CLK_divided256           0x08

/*@}*/ /* end of group DualTIMER */

/*----------------------------- UART  Controller (UART) -------------------------------*/
/** @addtogroup UART Universal Asynchronous Receiver/Transmitter
    memory mapped structure for UART
    @{
*/
typedef struct
{
        __RW    uint32_t    DATA;        /* !< Offset: 0x000 Data Register              */
        __RW    uint32_t    STATE;       /* !< Offset: 0x004 Status Register            */
        __RW    uint32_t    CTRL;        /* !< Offset: 0x008 Control Register           */
        union {                          /*                                             */
        __RO    uint32_t    INTSTATUS;   /* !< Offset: 0x00C Interrupt Status Register  */
        __WO    uint32_t    INTCLEAR;    /* !< Offset: 0x00C Interrupt Clear Register   */
        };                               /*                                             */
        __RW    uint32_t    BAUDDIV;     /* !< Offset: 0x010 Baudrate Divider Register  */

} UART_Type;

/* UART DATA Register Definitions */

#define UART_DATA_Pos                   0                                           /*!< UART_DATA_Pos: DATA Position   */
#define UART_DATA_Msk                   (0xFFul << UART_DATA_Pos)                   /*!< UART DATA: DATA Mask           */
                                                                                    /*                                  */
#define UART_STATE_RXOR_Pos             3                                           /*!< UART STATE: RXOR Position      */
#define UART_STATE_RXOR_Msk             (0x1ul << UART_STATE_RXOR_Pos)              /*!< UART STATE: RXOR Mask          */
                                                                                    /*                                  */
#define UART_STATE_TXOR_Pos             2                                           /*!< UART STATE: TXOR Position      */
#define UART_STATE_TXOR_Msk             (0x1ul << UART_STATE_TXOR_Pos)              /*!< UART STATE: TXOR Mask          */
                                                                                    /*                                  */
#define UART_STATE_RXBF_Pos             1                                           /*!< UART STATE: RXBF Position      */
#define UART_STATE_RXBF_Msk             (0x1ul << UART_STATE_RXBF_Pos)              /*!< UART STATE: RXBF Mask          */
                                                                                    /*                                  */
#define UART_STATE_TXBF_Pos             0                                           /*!< UART STATE: TXBF Position      */
#define UART_STATE_TXBF_Msk             (0x1ul << UART_STATE_TXBF_Pos )             /*!< UART STATE: TXBF Mask          */
                                                                                    /*                                  */
#define UART_CTRL_HSTM_Pos              6                                           /*!< UART CTRL: HSTM Position       */
#define UART_CTRL_HSTM_Msk              (0x01ul << UART_CTRL_HSTM_Pos)              /*!< UART CTRL: HSTM Mask           */
                                                                                    /*                                  */
#define UART_CTRL_RXORIRQEN_Pos         5                                           /*!< UART CTRL: RXORIRQEN Position  */
#define UART_CTRL_RXORIRQEN_Msk         (0x01ul << UART_CTRL_RXORIRQEN_Pos)         /*!< UART CTRL: RXORIRQEN Mask      */
                                                                                    /*                                  */
#define UART_CTRL_TXORIRQEN_Pos         4                                           /*!< UART CTRL: TXORIRQEN Position  */
#define UART_CTRL_TXORIRQEN_Msk         (0x01ul << UART_CTRL_TXORIRQEN_Pos)         /*!< UART CTRL: TXORIRQEN Mask      */
                                                                                    /*                                  */
#define UART_CTRL_RXIRQEN_Pos           3                                           /*!< UART CTRL: RXIRQEN Position    */
#define UART_CTRL_RXIRQEN_Msk           (0x01ul << UART_CTRL_RXIRQEN_Pos)           /*!< UART CTRL: RXIRQEN Mask        */
                                                                                    /*                                  */
#define UART_CTRL_TXIRQEN_Pos           2                                           /*!< UART CTRL: TXIRQEN Position    */
#define UART_CTRL_TXIRQEN_Msk           (0x01ul << UART_CTRL_TXIRQEN_Pos)           /*!< UART CTRL: TXIRQEN Mask        */
                                                                                    /*                                  */
#define UART_CTRL_RXEN_Pos              1                                           /*!< UART CTRL: RXEN Position       */
#define UART_CTRL_RXEN_Msk              (0x01ul << UART_CTRL_RXEN_Pos)              /*!< UART CTRL: RXEN Mask           */
                                                                                    /*                                  */
#define UART_CTRL_TXEN_Pos              0                                           /*!< UART CTRL: TXEN Position       */
#define UART_CTRL_TXEN_Msk              (0x01ul << UART_CTRL_TXEN_Pos)              /*!< UART CTRL: TXEN Mask           */
                                                                                    /*                                  */
#define UART_INTSTATUS_RXORIRQ_Pos      3                                           /*!< UART CTRL: RXORIRQ Position    */
#define UART_CTRL_RXORIRQ_Msk           (0x01ul << UART_INTSTATUS_RXORIRQ_Pos)      /*!< UART CTRL: RXORIRQ Mask        */
                                                                                    /*                                  */
#define UART_CTRL_TXORIRQ_Pos           2                                           /*!< UART CTRL: TXORIRQ Position    */
#define UART_CTRL_TXORIRQ_Msk           (0x01ul << UART_CTRL_TXORIRQ_Pos)           /*!< UART CTRL: TXORIRQ Mask        */
                                                                                    /*                                  */
#define UART_CTRL_RXIRQ_Pos             1                                           /*!< UART CTRL: RXIRQ Position      */
#define UART_CTRL_RXIRQ_Msk             (0x01ul << UART_CTRL_RXIRQ_Pos)             /*!< UART CTRL: RXIRQ Mask          */
                                                                                    /*                                  */
#define UART_CTRL_TXIRQ_Pos             0                                           /*!< UART CTRL: TXIRQ Position      */
#define UART_CTRL_TXIRQ_Msk             (0x01ul << UART_CTRL_TXIRQ_Pos)             /*!< UART CTRL: TXIRQ Mask          */
                                                                                    /*                                  */
#define UART_BAUDDIV_Pos                0                                           /*!< UART BAUDDIV: BAUDDIV Position */
#define UART_BAUDDIV_Msk                (0xFFFFFul << UART_BAUDDIV_Pos)             /*!< UART BAUDDIV: BAUDDIV Mask     */

#define UART_TX                         ( UART_CTRL_TXEN_Msk                      )
#define UART_RX                         ( UART_CTRL_RXEN_Msk                      )
#define UART_TRX                        ( UART_TX       + UART_RX                 )
#define UART_TX_IRQ                     ( UART_TX       + UART_CTRL_TXIRQEN_Msk   )
#define UART_RX_IRQ                     ( UART_RX       + UART_CTRL_RXIRQEN_Msk   )
#define UART_TRX_IRQ                    ( UART_TX_IRQ   + UART_RX_IRQ             )
#define UART_TX_ORIRQ                   ( UART_TX       + UART_CTRL_TXORIRQEN_Msk )
#define UART_RX_ORIRQ                   ( UART_RX       + UART_CTRL_RXORIRQEN_Msk )
#define UART_TRX_ORIRQ                  ( UART_TX_ORIRQ + UART_RX_ORIRQ           )

/*@}*/ /* end of group UART */

/*----------------------------- WDT Controller (WDT) -----------------------------*/
/** @addtogroup WDT Watch Dog Timer Controller(WDT)
    Memory Mapped Structure for Watchdog Timer
    @{
*/

typedef struct
{
        __RW    uint32_t    LOAD;                   /* !< Watchdog Load Register                        */
        __RO    uint32_t    VALUE;                  /* !< Watchdog Value Register                       */
        __RW    uint32_t    CTRL;                   /* !< Watchdog Control Register                     */
        __WO    uint32_t    INTCLR;                 /* !< Watchdog Clear Interrupt Register             */
        __RO    uint32_t    RAWINTSTAT;             /* !< Watchdog Raw Interrupt Status Register        */
        __RO    uint32_t    MASKINTSTAT;            /* !< Watchdog Interrupt Status Register            */
                uint32_t    WDT_RESERVED0[762];     /*                                                  */
        __RW    uint32_t    LOCK;                   /* !< Watchdog Lock Register                        */
                uint32_t    WDT_RESERVED1[191];     /*                                                  */
        __RW    uint32_t    ITCR;                   /* !< Watchdog Integration Test Control Register    */
        __WO    uint32_t    ITOP;                   /* !< Watchdog Integration Test Output Set Register */
} WDT_Type;

/* WATCHDOG CTRL Register Definitions */

#define WATCHDOG_LOAD_Pos                    0                                          /*!< WATCHDOG LOAD: LOAD Position                                   */
#define WATCHDOG_LOAD_Msk                   (0xFFFFFFFFul << WATCHDOG_LOAD_Pos)         /*!< WATCHDOG LOAD: LOAD Mask                                       */
                                                                                        /*                                                                  */
#define WATCHDOG_VALUE_Pos                   0                                          /*!< WATCHDOG VALUE: VALUE Position                                 */
#define WATCHDOG_VALUE_Msk                  (0xFFFFFFFFul << WATCHDOG_VALUE_Pos)        /*!< WATCHDOG VALUE: VALUE Mask                                     */
                                                                                        /*                                                                  */
#define WATCHDOG_CTRL_RESEN_Pos              1                                          /*!< WATCHDOG CTRL_RESEN: Enable Reset Output Position              */
#define WATCHDOG_CTRL_RESEN_Msk             (0x1ul << WATCHDOG_CTRL_RESEN_Pos)          /*!< WATCHDOG CTRL_RESEN: Enable Reset Output Mask                  */
                                                                                        /*                                                                  */
#define WATCHDOG_CTRL_INTEN_Pos              0                                          /*!< WATCHDOG CTRL_INTEN: Int Enable Position                       */
#define WATCHDOG_CTRL_INTEN_Msk             (0x1ul << WATCHDOG_CTRL_INTEN_Pos)          /*!< WATCHDOG CTRL_INTEN: Int Enable Mask                           */
                                                                                        /*                                                                  */
#define WATCHDOG_INTCLR_Pos                  0                                          /*!< WATCHDOG INTCLR: Int Clear Position                            */
#define WATCHDOG_INTCLR_Msk                 (0x1ul << WATCHDOG_INTCLR_Pos)              /*!< WATCHDOG INTCLR: Int Clear Mask                                */
                                                                                        /*                                                                  */
#define WATCHDOG_RAWINTSTAT_Pos              0                                          /*!< WATCHDOG RAWINTSTAT: Raw Int Status Position                   */
#define WATCHDOG_RAWINTSTAT_Msk             (0x1ul << WATCHDOG_RAWINTSTAT_Pos)          /*!< WATCHDOG RAWINTSTAT: Raw Int Status Mask                       */
                                                                                        /*                                                                  */
#define WATCHDOG_MASKINTSTAT_Pos             0                                          /*!< WATCHDOG MASKINTSTAT: Mask Int Status Position                 */
#define WATCHDOG_MASKINTSTAT_Msk            (0x1ul << WATCHDOG_MASKINTSTAT_Pos)         /*!< WATCHDOG MASKINTSTAT: Mask Int Status Mask                     */
                                                                                        /*                                                                  */
#define WATCHDOG_LOCK_Pos                    0                                          /*!< WATCHDOG LOCK: LOCK Position                                   */
#define WATCHDOG_LOCK_Msk                   (0x1ul << WATCHDOG_LOCK_Pos)                /*!< WATCHDOG LOCK: LOCK Mask                                       */
                                                                                        /*                                                                  */
#define WATCHDOG_INTEGTESTEN_Pos             0                                          /*!< WATCHDOG INTEGTESTEN: Integration Test Enable Position         */
#define WATCHDOG_INTEGTESTEN_Msk            (0x1ul << WATCHDOG_INTEGTESTEN_Pos)         /*!< WATCHDOG INTEGTESTEN: Integration Test Enable Mask             */
                                                                                        /*                                                                  */
#define WATCHDOG_INTEGTESTOUTSET_Pos         1                                          /*!< WATCHDOG INTEGTESTOUTSET: Integration Test Output Set Position */
#define WATCHDOG_INTEGTESTOUTSET_Msk        (0x1ul << WATCHDOG_INTEGTESTOUTSET_Pos      /*!< WATCHDOG INTEGTESTOUTSET: Integration Test Output Set Mask     */

#define WDT_IRQ                           ( WDT_CTRL_INTEN_Msk           )
#define WDT_RESET_IRQ                     ( WDT_IRQ + WDT_CTRL_RESEN_Msk )

/*@}*/ /* end of group  WATCHDOG */


/*------------------------------ GPIO Controller ------------------------------*/
/** @addtogroup GPIO
    Memory Mapped Structure for GPIO
    @{
  */

typedef struct
{
        __RW    uint32_t    P00   :   1;        /* Pn.0  */
        __RW    uint32_t    P01   :   1;        /* Pn.1  */
        __RW    uint32_t    P02   :   1;        /* Pn.2  */
        __RW    uint32_t    P03   :   1;        /* Pn.3  */
        __RW    uint32_t    P04   :   1;        /* Pn.4  */
        __RW    uint32_t    P05   :   1;        /* Pn.5  */
        __RW    uint32_t    P06   :   1;        /* Pn.6  */
        __RW    uint32_t    P07   :   1;        /* Pn.7  */
        __RW    uint32_t    P08   :   1;        /* Pn.8  */
        __RW    uint32_t    P09   :   1;        /* Pn.9  */
        __RW    uint32_t    P10   :   1;        /* Pn.10 */
        __RW    uint32_t    P11   :   1;        /* Pn.11 */
        __RW    uint32_t    P12   :   1;        /* Pn.12 */
        __RW    uint32_t    P13   :   1;        /* Pn.13 */
        __RW    uint32_t    P14   :   1;        /* Pn.14 */
        __RW    uint32_t    P15   :   1;        /* Pn.15 */
        __RW    uint32_t    P16   :   1;        /* Pn.16 */
        __RW    uint32_t    P17   :   1;        /* Pn.17 */
        __RW    uint32_t    P18   :   1;        /* Pn.18 */
        __RW    uint32_t    P19   :   1;        /* Pn.19 */
        __RW    uint32_t    P20   :   1;        /* Pn.20 */
        __RW    uint32_t    P21   :   1;        /* Pn.21 */
        __RW    uint32_t    P22   :   1;        /* Pn.22 */
        __RW    uint32_t    P23   :   1;        /* Pn.23 */
} Pin_Def;

typedef struct
{
        union {
        __RW    uint32_t    DATA;                   /* !< Offset: 0x0000 Data Register            */
        __RW    Pin_Def     DATA_PIN;               /*                                            */
        };                                          /*                                            */
        union {                                     /*                                            */
        __RW    uint32_t    DATAOUT;                /* !< Offset: 0x0004 DataOut Register         */
        __RW    Pin_Def     DATAOUT_PIN;            /*                                            */
        };                                          /*                                            */
        union {                                     /*                                            */
        __RW    uint32_t    PUN;                    /* !< Offset: 0x0008 Pull Up Set Register     */
        __RW    Pin_Def     PUN_PIN;                /*                                            */
        };                                          /*                                            */
        union {                                     /*                                            */
        __RW    uint32_t    WUN;                    /* !< Offset: 0x000C Wake up Set Register     */
        __RW    Pin_Def     WUN_PIN;                /*                                            */
        };                                          /*                                            */
        union {                                     /*                                            */
        __RW    uint32_t    OUTENABLESET;           /* !< Offset: 0x0010 OUTENSET Register        */
        __RW    Pin_Def     OUTENABLESET_PIN;       /*                                            */
        };                                          /*                                            */
        union {                                     /*                                            */
        __RW    uint32_t    OUTENABLECLR;           /* !< Offset: 0x0014 OUTENCLR Register        */
        __WO    Pin_Def     OUTENABLECLR_PIN;       /*                                            */
        };                                          /*                                            */
        union {                                     /*                                            */
        __RW    uint32_t    ALTFUNCSET;             /* !< Offset: 0x0018 ALTFUNCSET Register      */
        __RW    Pin_Def     ALTFUNCSET_PIN;         /*                                            */
        };                                          /*                                            */
        union {                                     /*                                            */
        __RW    uint32_t    ALTFUNCCLR;             /* !< Offset: 0x001C ALTFUNCSET Register      */
        __RW    Pin_Def     ALTFUNCCLR_PIN;         /*                                            */
        };                                          /*                                            */
        union {                                     /*                                            */
        __RW    uint32_t    INTENSET;               /* !< Offset: 0x0020 INTENSET Register        */
        __RW    Pin_Def     INTENSET_PIN;           /*                                            */
        };                                          /*                                            */
        union {                                     /*                                            */
        __RW    uint32_t    INTENCLR;               /* !< Offset: 0x024 INTENCLR Register         */
        __RW    Pin_Def     INTENCLR_PIN;           /*                                            */
        };                                          /*                                            */
        union {                                     /*                                            */
        __RW    uint32_t    INTTYPESET;             /* !< Offset: 0x028 INTTYPESET Register       */
        __RW    Pin_Def     INTTYPESET_PIN;         /*                                            */
        };                                          /*                                            */
        union {                                     /*                                            */
        __RW    uint32_t    INTTYPECLR;             /* !< Offset: 0x02C INTTYPECLR Register       */
        __RW    Pin_Def     INTTYPECLR_PIN;         /*                                            */
        };                                          /*                                            */
        union {                                     /*                                            */
        __RW    uint32_t    INTPOLSET;              /* !< Offset: 0x030 INTPOLSET Register        */
        __RW    Pin_Def     INTPOLSET_PIN;          /*                                            */
        };                                          /*                                            */
        union {                                     /*                                            */
        __RW    uint32_t    INTPOLCLR;              /* !< Offset: 0x034 INTPOLCLR Register        */
        __RW    Pin_Def     INTPOLCLR_PIN;          /*                                            */
        };                                          /*                                            */
        union {                                     /*                                            */
        __RO    uint32_t    INTSTATUS;              /* !< Offset: 0x038 Interrupt Status Register */
        __WO    uint32_t    INTCLEAR;               /* !< Offset: 0x038 Interrupt Clear Register  */     
        };                  
                uint32_t    RESERVED1[241];
         __RW   uint32_t    LB_MASKED[256];         /*!< Offset: 0x400 - 0x7FC Lower byte Masked Access Register (R/W)  */
         __RW   uint32_t    UB_MASKED[256];         /*!< Offset: 0x800 - 0xBFC Upper byte Masked Access Register (R/W)  */
} GPIO_Type;

/* GPIO CTRL Register Definitions */

#define GPIO_DATA_Pos           0                                          /* !< GPIO DATA: DATA Position           */
#define GPIO_DATA_Msk           (0xFFFFFFFFul << GPIO_DATA_Pos)            /* !< GPIO DATA: DATA Mask               */
                                                                           /*                                       */
#define GPIO_DATAOUT_Pos        0                                          /* !< GPIO DATAOUT: DATAOUT Position     */
#define GPIO_DATAOUT_Msk        (0xFFFFFFFFul << GPIO_DATAOUT_Pos)         /* !< GPIO DATAOUT: DATAOUT Mask         */
                                                                           /*                                       */
#define GPIO_PUN_Pos            0                                          /* !< GPIO DATAOUT: DATAOUT Position     */
#define GPIO_PUN_Msk            (0xFFFFFFFFul << GPIO_PUN_Pos)             /* !< GPIO DATAOUT: DATAOUT Mask         */
                                                                           /*                                       */
#define GPIO_WUN_Pos            0                                          /* !< GPIO DATAOUT: DATAOUT Position     */
#define GPIO_WUN_Msk            (0xFFFFFFFFul << GPIO_WUN_Pos)             /* !< GPIO DATAOUT: DATAOUT Mask         */
                                                                           /*                                       */
#define GPIO_OUTENSET_Pos       0                                          /* !< GPIO OUTEN: OUTEN Position         */
#define GPIO_OUTENSET_Msk       (0xFFFFFFFFul << GPIO_OUTENSET_Pos)        /* !< GPIO OUTEN: OUTEN Mask             */
                                                                           /*                                       */
#define GPIO_OUTENCLR_Pos       0                                          /* !< GPIO OUTEN: OUTEN Position         */
#define GPIO_OUTENCLR_Msk       (0xFFFFFFFFul << GPIO_OUTENCLR_Pos)        /* !< GPIO OUTEN: OUTEN Mask             */
                                                                           /*                                       */
#define GPIO_ALTFUNCSET_Pos     0                                          /* !< GPIO ALTFUNC: ALTFUNC Position     */
#define GPIO_ALTFUNCSET_Msk     (0xFFFFFFFFul << GPIO_ALTFUNCSET_Pos)      /* !< GPIO ALTFUNC: ALTFUNC Mask         */
                                                                           /*                                       */
#define GPIO_ALTFUNCCLR_Pos     0                                          /* !< GPIO ALTFUNC: ALTFUNC Position     */
#define GPIO_ALTFUNCCLR_Msk     (0xFFFFFFFFul << GPIO_ALTFUNCCLR_Pos)      /* !< GPIO ALTFUNC: ALTFUNC Mask         */
                                                                           /*                                       */
#define GPIO_INTENSET_Pos       0                                          /* !< GPIO INTEN: INTEN Position         */
#define GPIO_INTENSET_Msk       (0xFFFFFFFFul << GPIO_INTENSET_Pos)        /* !< GPIO INTEN: INTEN Mask             */
                                                                           /*                                       */
#define GPIO_INTENCLR_Pos       0                                          /* !< GPIO INTEN: INTEN Position         */
#define GPIO_INTENCLR_Msk       (0xFFFFFFFFul << GPIO_INTENCLR_Pos)        /* !< GPIO INTEN: INTEN Mask             */
                                                                           /*                                       */
#define GPIO_INTTYPESET_Pos     0                                          /* !< GPIO INTTYPE: INTTYPE Position     */
#define GPIO_INTTYPESET_Msk     (0xFFFFFFFFul << GPIO_INTTYPESET_Pos)      /* !< GPIO INTTYPE: INTTYPE Mask         */
                                                                           /*                                       */
#define GPIO_INTTYPECLR_Pos     0                                          /* !< GPIO INTTYPE: INTTYPE Position     */
#define GPIO_INTTYPECLR_Msk     (0xFFFFFFFFul << GPIO_INTTYPECLR_Pos)      /* !< GPIO INTTYPE: INTTYPE Mask         */
                                                                           /*                                       */
#define GPIO_INTPOLSET_Pos      0                                          /* !< GPIO INTPOL: INTPOL Position       */
#define GPIO_INTPOLSET_Msk      (0xFFFFFFFFul << GPIO_INTPOLSET_Pos)       /* !< GPIO INTPOL: INTPOL Mask           */
                                                                           /*                                       */
#define GPIO_INTPOLCLR_Pos      0                                          /* !< GPIO INTPOL: INTPOL Position       */
#define GPIO_INTPOLCLR_Msk      (0xFFFFFFFFul << GPIO_INTPOLCLR_Pos)       /* !< GPIO INTPOL: INTPOL Mask           */
                                                                           /*                                       */
#define GPIO_INTSTATUS_Pos      0                                          /* !< GPIO INTSTATUS: INTSTATUS Position */
#define GPIO_INTSTATUS_Msk      (0xFFFFFFFFul << GPIO_INTSTATUS_Pos)       /* !< GPIO INTSTATUS: INTSTATUS Mask     */
                                                                           /*                                       */
#define GPIO_INTCLEAR_Pos       0                                          /* !< GPIO INTCLEAR: INTCLEAR Position   */
#define GPIO_INTCLEAR_Msk       (0xFFFFFFFFul << GPIO_INTCLEAR_Pos)        /* !< GPIO INTCLEAR: INTCLEAR Mask       */


/*@}*/ /* end of group GPIO */

/*------------- System Control (SYSCON) --------------------------------------*/
/** @addtogroup SYSCON System Control
    @{
*/
typedef struct
{
    __RW   uint32_t  REMAP;         /*!< Offset: 0x000 Remap Control Register (R/W) */
    __RW   uint32_t  PMUCTRL;       /*!< Offset: 0x004 PMU Control Register (R/W) */
    __RW   uint32_t  RESETOP;       /*!< Offset: 0x008 Reset Option Register  (R/W) */
    __RW   uint32_t  EMICTRL;       /*!< Offset: 0x00C EMI Control Register  (R/W) */
    __RW   uint32_t  RSTINFO;       /*!< Offset: 0x010 Reset Information Register (R/W) */
} SYSCON_Type;

/* SYSCON CTRL Register Definitions */

#define SYSCON_REMAP_Pos                    0
#define SYSCON_REMAP_Msk                    (0x01ul << SYSCON_REMAP_Pos)                        /* !< SYSCON MEME_CTRL: REMAP Mask                */
                                                                                                /*                                                */
#define SYSCON_PMUCTRL_EN_Pos               0                                                   /*                                                */
#define SYSCON_PMUCTRL_EN_Msk               (0x01ul << SYSCON_PMUCTRL_EN_Pos)                   /* !< SYSCON PMUCTRL: PMUCTRL ENABLE Mask         */
                                                                                                /*                                                */
#define SYSCON_LOCKUPRST_RESETOP_Pos        0                                                   /*                                                */
#define SYSCON_LOCKUPRST_RESETOP_Msk        (0x01ul << SYSCON_LOCKUPRST_RESETOP_Pos)            /* !< SYSCON SYS_CTRL: LOCKUP RESET ENABLE Mask   */
                                                                                                /*                                                */
#define SYSCON_EMICTRL_SIZE_Pos             24                                                  /*                                                */
#define SYSCON_EMICTRL_SIZE_Msk             (0x00001ul << SYSCON_EMICTRL_SIZE_Pos)              /* !< SYSCON EMICTRL: SIZE Mask                   */
                                                                                                /*                                                */
#define SYSCON_EMICTRL_TACYC_Pos            16                                                  /*                                                */
#define SYSCON_EMICTRL_TACYC_Msk            (0x00007ul << SYSCON_EMICTRL_TACYC_Pos)             /* !< SYSCON EMICTRL: TURNAROUNDCYCLE Mask        */
                                                                                                /*                                                */
#define SYSCON_EMICTRL_WCYC_Pos             8                                                   /*                                                */
#define SYSCON_EMICTRL_WCYC_Msk             (0x00003ul << SYSCON_EMICTRL_WCYC_Pos)              /* !< SYSCON EMICTRL: WRITECYCLE Mask             */
                                                                                                /*                                                */
#define SYSCON_EMICTRL_RCYC_Pos             0                                                   /*                                                */
#define SYSCON_EMICTRL_RCYC_Msk             (0x00007ul << SYSCON_EMICTRL_RCYC_Pos)              /* !< SYSCON EMICTRL: READCYCLE Mask              */
                                                                                                /*                                                */
#define SYSCON_RSTINFO_SYSRESETREQ_Pos      0                                                   /*                                                */
#define SYSCON_RSTINFO_SYSRESETREQ_Msk      (0x00001ul << SYSCON_RSTINFO_SYSRESETREQ_Pos)       /* !< SYSCON RSTINFO: SYSRESETREQ Mask            */
                                                                                                /*                                                */
#define SYSCON_RSTINFO_WDOGRESETREQ_Pos     1                                                   /*                                                */
#define SYSCON_RSTINFO_WDOGRESETREQ_Msk     (0x00001ul << SYSCON_RSTINFO_WDOGRESETREQ_Pos)      /* !< SYSCON RSTINFO: WDOGRESETREQ Mask           */
                                                                                                /*                                                */
#define SYSCON_RSTINFO_LOCKUPRESET_Pos      2                                                   /*                                                */
#define SYSCON_RSTINFO_LOCKUPRESET_Msk      (0x00001ul << SYSCON_RSTINFO_LOCKUPRESET_Pos)       /* !< SYSCON RSTINFO: LOCKUPRESET Mask            */

/*@}*/ /* end of group SYSCON */

/*------------------------------ FLASH Controller ------------------------------*/
/** @addtogroup FLASH Controller
    Memory Mapped Structure for FLASH
    @{
  */

typedef struct
{
        __RW    uint32_t    MODECTRL;                   /* !< Offset: 0x000 Flash Mone Control Register               */
        __RW    uint32_t    FLASHCTRL;                  /* !< Offset: 0x004 Flash Control Register                    */
        __RW    uint32_t    IAPCTRL;                    /* !< Offset: 0x008 Flash IAP Control Register                */
        __RW    uint32_t    ADDRESS;                    /* !< Offset: 0x00C Flash IAP Start Address Register          */
        __RW    uint32_t    PASSWORD[2];                /* !< Offset: 0x010 - 0x014 Flash IAP Password Register       */
        __RW    uint32_t    PASSWORDGOAL[2];            /* !< Offset: 0x018 - 0x01C Flash IAP Password Goal Register  */
                uint32_t    FLASH_Reserved0[56];        /* !< Offset: 0x020 - 0x0FC Reserved                          */
        union {                                         /*                                                            */
        __RW    uint32_t    DATA[32];                   /* !< Offset: 0x100 - 0x17F Flash IAP Data Register           */
        __RW    uint8_t     data[128];                  /*                                                            */
        };                                              /*                                                            */
                uint32_t    FLASH_Reserved1[32];        /* !< Offset: 0x180 - 0x0200 Reserved                         */
        __RW    uint32_t    SECTPROECT;                 /* !< Offset: 0x200 Flash IAP Sect Proect Register            */
} FLASH_Type;

/*@}*/ /* end of group FLASH */

/*------------------------------ POWER Controller ------------------------------*/
/** @addtogroup POWER Controller
    Memory Mapped Structure for Power
    @{
  */

typedef struct
{
        __RW    uint32_t    BATTERY;                    /* !< Offset: 0x000 BATTERY Detect Register      */
        __WO    uint32_t    FLASHPOWERCTRL;             /* !< Offset: 0x004 Flash Power Control Register */
        union {                                         /*                                               */
        __RW    uint32_t    POWERCTRL1;                 /* !< Offset: 0x008 Power Control I Register     */
        struct {                                        /*                                               */
        __RW    uint8_t     PMCTRL;                     /*                                               */
                uint8_t     POWERCTRL_RESERVED[3];      /*                                               */
        }powerctrl1;                                    /*                                               */
        };                                              /*                                               */
        __RW    uint32_t    POWERCTRL2;                 /* !< Offset: 0x00C Power Control II Register    */
                uint32_t    RF_RESERVED0[4];            /* !< Offset: 0x010 - 0x01C Reserved             */
        __RW    uint32_t    CHARGECTRL;                 /* !< Offset: 0x020 Charge Control Register      */
                uint32_t    RF_RESERVED1[7];            /* !< Offset: 0x024 - 0x03C Reserved             */
        __RW    uint32_t    RCCTRL1;                    /* !< Offset: 0x040 RC Control I Register        */
        __RW    uint32_t    RCCTRL2;                    /* !< Offset: 0x044 RC Control II Register       */
        __RW    uint32_t    RCTARGET;                   /* !< Offset: 0x048 RC Target Register           */
                uint32_t    RF_RESERVED2;               /* !< Offset: 0x04C Reserved                     */
        __RW    uint32_t    XRCCTRL1;                   /* !< Offset: 0x050 XRC Control I Register       */
        __RW    uint32_t    XRCCTRL2;                   /* !< Offset: 0x054 XRC Control II Register      */
        __RW    uint32_t    XRCTARGET;                  /* !< Offset: 0x058 XRC Target Register          */
} POWER_Type;

/* POWER CTRL Register Definitions */

#define POWER_CTRL_STOP_Pos         0                                        /*!< POWER CTRL: Stop Mode Position */
#define POWER_CTRL_STOP_Msk         (0x01ul << POWER_CTRL_STOP_Pos)          /*!< POWER CTRL: Stop Mode Mask     */
                                                                             /*                                  */
#define POWER_PM3S_Pos              1                                        /*!< POWER CTRL: PM3S Position      */
#define POWER_PM3S_Msk              (0x01ul << POWER_PM3S_Pos)               /*!< POWER CTRL: PM3S Mask          */
                                                                             /*                                  */
#define POWER_REGAE_Pos             2                                        /*!< POWER CTRL: REGAE Position     */
#define POWER_REGAE_Msk             (0x01ul << POWER_REGAE_Pos)              /*!< POWER CTRL: REGAE Mask         */
                                                                             /*                                  */
#define POWER_QD_Pos                3                                        /*!< POWER CTRL: QD Position        */
#define POWER_QD_Msk                (0x01ul << POWER_QD_Pos)                 /*!< POWER CTRL: QD Mode Mask       */
                                                                             /*                                  */
#define POWER_PM1S_Pos              4                                        /*!< POWER CTRL: PM1S Position      */
#define POWER_PM1S_Msk              (0x01ul << POWER_PM1S_Pos)               /*!< POWER CTRL: PM1S Mask          */
                                                                             /*                                  */
#define POWER_PORFCLR_Pos           16                                       /*!< POWER CTRL: PORFCLR Position   */
#define POWER_PORFCLR_Msk           (0x01ul << POWER_PORFCLR_Pos)            /*!< POWER CTRL: PORFCLR Mask       */
                                                                             /*                                  */
#define POWER_RESTENFCLR_Pos        17                                       /*!< POWER CTRL: RESTENFCLR Position*/
#define POWER_RESTENFCLR_Msk        (0x01ul << POWER_RESTENFCLR_Pos)         /*!< POWER CTRL: RESTENFCLR Mask    */
                                                                             /*                                  */
#define POWER_BODFCLR_Pos           18                                       /*!< POWER CTRL: BODFCLR Position   */
#define POWER_BODFCLR_Msk           (0x01ul << POWER_BODFCLR_Pos)            /*!< POWER CTRL: BODFCLR Mask       */
                                                                             /*                                  */
#define POWER_PD_LVD_Pos            23                                       /*!< POWER CTRL: PD_LVD Position    */
#define POWER_PD_LVD_Msk            (0x01ul << POWER_PD_LVD_Pos)             /*!< POWER CTRL: PD_LVD Mask        */

#define PM1                         ( POWER_CTRL_STOP_Msk + POWER_PM1S_Msk )
#define PM2                         ( POWER_CTRL_STOP_Msk + POWER_QD_Msk   )
#define PM3                         ( POWER_CTRL_STOP_Msk + POWER_PM3S_Msk )

/*@}*/ /* end of group power */

/*------------------------------ RADIO Controller ------------------------------*/
/** @addtogroup RADIO Controller
    Memory Mapped Structure for RADIO
    @{
  */

typedef struct
{
        __WO    uint32_t    RESET;                  /* !< Offset: 0x000 RF_RESET Register              */
        __RW    uint32_t    STROBE;                 /* !< Offset: 0x004 Strobe Command Register        */
        __RW    uint32_t    MODECTRL;               /* !< Offset: 0x008 Mode Control Register          */
                uint32_t    RF_RESERVED0[1];        /* !< Offset: 0x00C Reserved                       */
        __RO    uint32_t    STATUS;                 /* !< Offset: 0x010 STATUS Register                */
        __RW    uint32_t    INTSTATE;               /* !< Offset: 0x014 RF Interrupt State Register    */
        union {                                     /*                                                 */
        __RW    uint32_t    SYNC_ID32b[2];          /* !< Offset: 0x018 SYNC ID Register               */
        __RW    uint8_t     SYNC_ID8b[8];           /*                                                 */
        };                                          /*                                                 */
        __RW    uint32_t    FIFOCTRL;               /* !< Offset: 0x020 FIFO Control Register          */
        __RW    uint32_t    DATARATE;               /* !< Offset: 0x024 Data Rate Register             */
        union {                                     /*                                                 */
        __RW    uint32_t    RFGIO;                  /* !< Offset: 0x028 RF GIO Register                */
        struct {                                    /*                                                 */
        __RW    uint8_t     RFGPIO1;                  /*                                                 */
        __RW    uint8_t     RFGPIO2;                  /*                                                 */
        __RW    uint8_t     RFCKO;                  /*                                                 */
                uint8_t     RFGIO_Reserved;         /*                                                 */
        } rfgio;                                    /*                                                 */
        };                                          /*                                                 */
                uint32_t    RF_RESERVED2[21];       /* !< Offset: 0x02C - 0x7C Reserved                */
        __RW    uint32_t    CALIBRATION;            /* !< Offset: 0x080 Calibration Register           */
        __RW    uint32_t    IFCTRL;                 /* !< Offset: 0x084 IF Control Register            */
        __RW    uint32_t    VCOC;                   /* !< Offset: 0x088 VCO Current Register           */
        __RW    uint32_t    VCOBAND;                /* !< Offset: 0x08C VCO BAND Register              */
        __RW    uint32_t    VCODEV1;                /* !< Offset: 0x090 VCO Deviation I Register       */
        __RW    uint32_t    VCODEV2;                /* !< Offset: 0x094 VCO Deviation II Register      */
                uint32_t    RF_RESERVED3[10];       /* !< Offset: 0x098 - 0x0BC Reserved               */
        __RW    uint32_t    CHANNEL;                /* !< Offset: 0x0C0 Channel Register               */
        __RW    uint32_t    FREQUENCY1;             /* !< Offset: 0x0C4 RF Frequency I Register        */
        __RW    uint32_t    FREQUENCY2;             /* !< Offset: 0x0C8 RF Frequency II Register       */
        __RW    uint32_t    CHGROUP;                /* !< Offset: 0x0CC Channel Group Register         */
                uint32_t    RF_RESERVED4[12];       /* !< Offset: 0x0B0 - 0x0FC Reserved               */
        __WO    uint32_t    TXCTRL;                 /* !< Offset: 0x100 TX Control Register            */
        __WO    uint32_t    TXPOWER;                /* !< Offset: 0x104 TX Power Register              */
        __WO    uint32_t    TXMODCTRL;              /* !< Offset: 0x108 TX Modulation Control Register */
        __WO    uint32_t    TXMOD;                  /* !< Offset: 0x10C TX Modulation Register         */
                uint32_t    RF_RESERVED5[12];       /* !< Offset: 0x110 - 0x13C Reserved               */
        __RW    uint32_t    RXCTRL;                 /* !< Offset: 0x140 RX Control Register            */
        __RW    uint32_t    RXGAIN1;                /* !< Offset: 0x144 RX Gain I Register             */
        __WO    uint32_t    RXGAIN2;                /* !< Offset: 0x148 RX Gain II Register            */
                uint32_t    RF_RESERVED6[1];        /* !< Offset: 0x14C Reserved                       */
        __RW    uint32_t    RXDEM1;                 /* !< Offset: 0x150 RX Demodulation I Register     */
        __RW    uint32_t    RXDEM2;                 /* !< Offset: 0x154 RX Demodulation II Register    */
                uint32_t    RF_RESERVED7[10];       /* !< Offset: 0x158 - 0x17C Reserved               */
        __WO    uint32_t    CODE;                   /* !< Offset: 0x180 CODE Register                  */
        __WO    uint32_t    WS;                     /* !< Offset: 0x184 WS Register                    */
        __WO    uint32_t    CRCPL;                  /* !< Offset: 0x188 CRCPL Register                 */
        __WO    uint32_t    CRCIV;                  /* !< Offset: 0x18C CRCIV Register                 */
                uint32_t    RF_RESERVED8[12];       /* !< Offset: 0x190 - 0x1BC Reserved               */
        __RW    uint32_t    DELAY;                  /* !< Offset: 0x1C0 DELAY Register                 */
        __RW    uint32_t    CLOCKCTRL1;             /* !< Offset: 0x1C4 RF Clock Control I Register    */
        __WO    uint32_t    CLOCKCTRL2;             /* !< Offset: 0x1C8 RF Clock Control II Register   */
        __WO    uint32_t    Reserved9[1];           /* !< Offset: 0x1CC Reserved                       */
        __WO    uint32_t    CPC;                    /* !< Offset: 0x1D0 Charge Pump Register           */
        __RW    uint32_t    RFTEST1;                /* !< Offset: 0x1D4 RF Test I Register             */
        __RW    uint32_t    RFTEST2;                /* !< Offset: 0x1D8 RF Test II Register            */
        __RW    uint32_t    RFTEST3;                /* !< Offset: 0x1DC RF Test III Register           */
        __RW    uint32_t    RFTEST4;                /* !< Offset: 0x1E0 RF Test IV Register            */
        __RW    uint32_t    RFTEST5;                /* !< Offset: 0x1E4 RF Test V Register             */
                uint32_t    RF_RESERVED10[6];       /* !< Offset: 0x1E0 - 0x1FC Reserved               */
        __RW    uint32_t    TimerWakeup;            /* !< Offset: 0x200 Timer Wake up Register         */
        __WO    uint32_t    RBTO;                   /* !< Offset: 0x204 RBTO Register                  */
        __WO    uint32_t    RBT;                    /* !< Offset: 0x208 RBT Register                   */
                uint32_t    RF_RESERVED11[13];      /* !< Offset: 0x20C - 0x23C Reserved               */
        __RW    uint32_t    ADCCTRL;                /* !< Offset: 0x240 8-bit ADC Control Register     */
        __RW    uint32_t    ADC;                    /* !< Offset: 0x244 8-bit ADC Threshold Register   */
        __RW    uint32_t    ADCCAL;                 /* !< Offset: 0x248 8-bit ADC Calibration Register */
                uint32_t    RF_RESERVED12[45];      /* !< Offset: 0x24C - 0x2FC Reserved               */
        __RW    uint32_t    MODESEL;                /* !< Offset: 0x300 MODESEL Register               */
        __RW    uint32_t    CSMACACTL;              /* !< Offset: 0x304 CSMA_CA Register               */
        __WO    uint32_t    ARTCTL;                 /* !< Offset: 0x308 ART Register                   */
        __WO    uint32_t    ACKCTL;                 /* !< Offset: 0x30C ACK Register                   */
        __RW    uint32_t    LQICTL;                 /* !< Offset: 0x310 LQI Register                   */
        __WO    uint32_t    ADFCTL;                 /* !< Offset: 0x314 ADFC Register                  */
        __WO    uint32_t    PID;                    /* !< Offset: 0x318 PID Register                   */
        __WO    uint32_t    SADD;                   /* !< Offset: 0x31C SADD Register                  */
        __WO    uint32_t    LADD[2];                /* !< Offset: 0x320 - 0x324 LADD Register          */
        __RW    uint32_t    PNG;                    /* !< Offset: 0x328 PNG Register )                 */
                uint32_t    RF_RESERVED13[53];      /* !< Offset: 0x32C - 0x3FC Reserved               */
        union {                                     /*                                                 */
        __RW    uint32_t    FIFO32b[64];            /* !< Offset: 0x400 - 0x4FF FIFO Register          */
        __RW    uint32_t    FIFO8b[256];            /* !< Offset: 0x400 - 0x4FF FIFO Register          */
        };
} RADIO_Type;

/*@}*/ /* end of group RADIO */

/*------------------------------ SPI Controller ------------------------------*/
/** @addtogroup SPI Controller
    Memory Mapped Structure for SPI
    @{
  */

typedef struct
{
        __RW    uint32_t    CTRL;               /* !< Offset: 0x000 SPI Control Register              */
        __RW    uint32_t    STATUS;             /* !< Offset: 0x004 SPI Status Register               */
        __RW    uint32_t    INTST;              /* !< Offset: 0x008 SPI INT Status Register           */
        __RW    uint32_t    SSCTRL;             /* !< Offset: 0x00C SPI Slave Select Control Register */
        __RW    uint32_t    TXFIFOSTATUS;       /* !< Offset: 0x010 TX FIFO Status Register           */
        __RW    uint32_t    RXFIFOSTATUS;       /* !< Offset: 0x014 RX FIFO Status Register           */
        __RW    uint32_t    TXFIFO;             /* !< Offset: 0x018 TX FIFO Register                  */
        __RW    uint32_t    RXFIFO;             /* !< Offset: 0x01C RX FIFO Register                  */
} SPI_Type;

/* SPI CTRL Register Definitions */

#define SPI_CPHA_Pos                2                                        /* !< SPI_CPHA CPHA Position                         */
#define SPI_CPHA_Msk                (0xFFul << SPI_CPHA_Pos)                 /* !< SPI_CPHA: CPHA Mask                            */
                                                                             /*                                                   */
#define SPI_CPOL_Pos                3                                        /* !< SPI_CPOL: CPOL Position                        */
#define SPI_CPOL_Msk                (0x1ul << SPI_CPOL_Pos)                  /* !< SPI_CPOL: CPOL Mask                            */
                                                                             /*                                                   */
#define SPI_MSTR_Pos                4                                        /* !< SPI MSTR: MSTR Position                        */
#define SPI_MSTR_Msk                (0x1ul << SPI_MSTR_Pos)                  /* !< SPI MSTR: MSTR Mask                            */
                                                                             /*                                                   */
#define SPI_SPIEN_Pos               6                                        /* !< SPI SPIEN: SPIEN Position                      */
#define SPI_SPIEN_Msk               (0x1ul << SPI_SPIEN_Pos)                 /* !< SPI SPIEN: SPIEN Mask                          */
                                                                             /*                                                   */
#define SPI_SPIIRQ_Pos              7                                        /* !< SPI SPIIRQ: IRQ Position                       */
#define SPI_SPIIRQ_Msk              (0x1ul << SPI_SPIIRQ_Pos )               /* !< SPI SPIIRQ: IRQ Mask                           */
                                                                             /*                                                   */
#define SPI_BitLength_Pos           8                                        /* !< SPI BitLength: Bit Length Position             */
#define SPI_BitLength_Msk           (0x0Ful << SPI_BitLength_Pos)            /* !< SPI BitLength: Bit Length Mask                 */
                                                                             /*                                                   */
#define SPI_FIFOEN_Pos              12                                       /* !< SPI_FIFOEN: FIFOEN Position                    */
#define SPI_FIFOEN_Msk              (0x01ul << SPI_FIFOEN_Pos)               /* !< SPI_FIFOEN: FIFOEN Mask                        */
                                                                             /*                                                   */
#define SPI_SlaveRST_Pos            15                                       /* !< SPI_SlaveRST: SlaveRST Position                */
#define SPI_SlaveRST_Msk            (0x01ul << SPI_SlaveRST_Pos)             /* !< SPI_SlaveRST: SlaveRST Mask                    */
                                                                             /*                                                   */
#define SPI_TXFIFO_INTLEVEL_Pos     16                                       /* !< SPI_TXFIFO_INTLEVEL: TXFIFO_INTLEVEL Position  */
#define SPI_TXFIFO_INTLEVEL_Msk     (0x07ul << SPI_TXFIFO_INTLEVEL_Pos)      /* !< SPI_TXFIFO_INTLEVEL: TXFIFO_INTLEVEL Mask      */
                                                                             /*                                                   */
#define SPI_RXFIFO_INTLEVEL_Pos     20                                       /* !< SPI_RXFIFO_INTLEVEL: RXFIFO_INTLEVEL Position  */
#define SPI_RXFIFO_INTLEVEL_Msk     (0x07ul << SPI_RXFIFO_INTLEVEL_Pos)      /* !< SPI_RXFIFO_INTLEVEL: RXFIFO_INTLEVEL Mask      */
                                                                             /*                                                   */
#define SPI_SlaveCTL_EN_Pos         0                                        /* !< SPI_SlaveCTL_EN: SlaveCTL_Enable Position      */
#define SPI_SlaveCTL_EN_Msk         (0x1ul << SPI_SlaveCTL_EN_Pos )          /* !< SPI_SlaveCTL_EN: SlaveCTL Enable Mask          */
                                                                             /*                                                   */
#define SPI_MODF_Pos                4                                        /* !< SPI MODF: MODF Position                        */
#define SPI_MODF_Msk                (0x1ul << SPI_MODF_Pos )                 /* !< SPI MODF: MODF Mask                            */
                                                                             /*                                                   */
#define SPI_SlaveCTL_STATUS_Pos     5                                        /* !< SPI_SlaveCTL_STATUS: SlaveCTL_STATUS Position  */
#define SPI_SlaveCTL_STATUS_Msk     (0x1ul << SPI_SlaveCTL_STATUS_Pos )      /* !< SPI_SlaveCTL_STATUS: SlaveCTL_STATUS Mask      */
                                                                             /*                                                   */
#define SPI_WCOL_Pos                6                                        /* !< SPI_WCOL: WCOL Position                        */
#define SPI_WCOL_Msk                (0x1ul << SPI_WCOL_Pos )                 /* !< SPI_WCOL: WCOL Mask                            */
                                                                             /*                                                   */
#define SPI_SPIF_Pos                7                                        /* !< SPI_SPIF: SPIF Position                        */
#define SPI_SPIF_Msk                (0x1ul << SPI_SPIF_Pos )                 /* !< SPI_SPIF: SPIF Mask                            */
                                                                             /*                                                   */
#define SPI_TXFIFO_INTEN_Pos        0                                        /* !< SPI_TXFIFO INTEN: TXFIFO INTEN Position        */
#define SPI_TXFIFO_INTEN_Msk        (0x01ul << SPI_TXFIFO_INTEN_Pos)         /* !< SPI_TXFIFO INTEN: TXFIFO INTEN Mask            */
                                                                             /*                                                   */
#define SPI_RXFIFO_INTEN_Pos        1                                        /* !< SPI_RXFIFO INTEN: RXFIFO INTEN Position        */
#define SPI_RXFIFO_INTEN_Msk        (0x01ul << SPI_RXFIFO_INTEN_Pos)         /* !< SPI_RXFIFO INTEN: RXFIFO INTEN Mask            */
                                                                             /*                                                   */
#define SPI_TXFIFO_INTF_Pos         4                                        /* !< SPI_RXFIFO INTF: RXFIFO INTF Position          */
#define SPI_TXFIFO_INTF_Msk         (0x01ul << SPI_TXFIFO_INTF_Pos)          /* !< SPI_RXFIFO INTF: RXFIFO INTF Mask              */
                                                                             /*                                                   */
#define SPI_RXFIFO_INTF_Pos         5                                        /* !< SPI_RXFIFO INTF: RXFIFO INTF Position          */
#define SPI_RXFIFO_INTF_Msk         (0x01ul << SPI_RXFIFO_INTF_Pos)          /* !< SPI_RXFIFO INTF: RXFIFO INTF Mask              */
                                                                             /*                                                   */
#define SPI_TXFIFO_REM_Pos          0                                        /* !< SPI_TXFIFO REM: TXFIFO REM Position            */
#define SPI_TXFIFO_REM_Msk          (0x07ul << SPI_TXFIFO_REM_Pos)           /* !< SPI_TXFIFO REM: TXFIFO REM Mask                */
                                                                             /*                                                   */
#define SPI_TXFIFO_EMPTY_Pos        3                                        /* !< SPI_TXFIFO EMPTY: TXFIFO EMPTY Position        */
#define SPI_TXFIFO_EMPTY_Msk        (0x01ul << SPI_TXFIFO_EMPTY_Pos)         /* !< SPI_TXFIFO EMPTY: TXFIFO EMPTY Mask            */
                                                                             /*                                                   */
#define SPI_TXFIFO_FULL_Pos         4                                        /* !< SPI_TXFIFO FULL: TXFIFO FULL Position          */
#define SPI_TXFIFO_FULL_Msk         (0x01ul << SPI_TXFIFO_FULL_Pos)          /* !< SPI_TXFIFO FULL: TXFIFO FULL Mask              */
                                                                             /*                                                   */
#define SPI_RXFIFO_REM_Pos          0                                        /* !< SPI_RXFIFO REM: RXFIFO REM Position            */
#define SPI_RXFIFO_REM_Msk          (0x07ul << SPI_RXFIFO_REM_Pos)           /* !< SPI_RXFIFO REM: RXFIFO REM Mask                */
                                                                             /*                                                   */
#define SPI_RXFIFO_EMPTY_Pos        3                                        /* !< SPI_RXFIFO EMPTY: RXFIFO EMPTY Position        */
#define SPI_RXFIFO_EMPTY_Msk        (0x01ul << SPI_RXFIFO_EMPTY_Pos)         /* !< SPI_RXFIFO EMPTY: RXFIFO EMPTY Mask            */
                                                                             /*                                                   */
#define SPI_RXFIFO_FULL_Pos         4                                        /* !< SPI_RXFIFO FULL: RXFIFO FULL Position          */
#define SPI_RXFIFO_FULL_Msk         (0x01ul << SPI_RXFIFO_FULL_Pos)          /* !< SPI_RXFIFO FULL: RXFIFO FULL Mask              */

#define SPI_MASTER                  ( SPI_SPIEN_Msk   + SPI_MSTR_Msk                                )
#define SPI_SLAVE                   ( SPI_SPIEN_Msk                                                 )
#define SPI_MASTER_IRQ              ( SPI_MASTER      + SPI_SPIIRQ_Msk                              )
#define SPI_SLAVE_IRQ               ( SPI_SLAVE       + SPI_SPIIRQ_Msk                              )
#define SPI_MASTER_FIFO             ( SPI_MASTER      + SPI_FIFOEN_Msk                              )
#define SPI_SLAVE_FIFO              ( SPI_SLAVE       + SPI_FIFOEN_Msk                              )
#define SPI_MASTER_FIFO_IRQ         ( SPI_MASTER_FIFO + SPI_TXFIFO_INTEN_Msk + SPI_RXFIFO_INTEN_Msk )
#define SPI_SLAVE_FIFO_IRQ          ( SPI_SLAVE_FIFO  + SPI_TXFIFO_INTEN_Msk + SPI_RXFIFO_INTEN_Msk )

#define SPI_CLK_devided4            0x00
#define SPI_CLK_devided8            0x01
#define SPI_CLK_devided16           0x02
#define SPI_CLK_devided32           0x03
#define SPI_CLK_devided64           0x20
#define SPI_CLK_devided128          0x21
#define SPI_CLK_devided256          0x22
#define SPI_CLK_devided512          0x23
/*@}*/ /* end of group SPI */

/*------------------------------ I2CM Controller ------------------------------*/
/** @addtogroup I2CM I2C Master
    Memory Mapped Structure for I2C Master
    @{
  */
typedef struct
{
    __RW    uint32_t  SLAVE_ADDR;        /*  !< Offset: 0x000    I2C Slave Address register                        */
                                         /*     [0]     - R/S(receive / not send). 0=SEND, 1=RECEIVE               */
                                         /*     [7:1]   - 7 address bits (A6-A0)                                   */
    union {                              /*                                                                        */
        __WO     uint32_t  CTRL;         /*  !< Offset: 0x004    I2C Master Control register                       */
                                         /*     [0]     - RUN                                                      */
                                         /*     [1]     - START                                                    */
                                         /*     [2]     - STOP                                                     */
                                         /*     [3]     - ACK                                                      */
                                         /*     [4]     - HS                                                       */
                                         /*     [5]     -                                                          */
                                         /*     [6]     - SLRST                                                    */
                                         /*     [7]     - RSTB                                                     */
        __RO     uint32_t  STATUS;       /*  !< Offset: 0x004    I2C Master Status register                        */
                                         /*     [0]     - BUSY      -                                              */
                                         /*     [1]     - ERROR                                                    */
                                         /*     [2]     - ADDR_ACK                                                 */
                                         /*     [3]     - DATA_ACK                                                 */
                                         /*     [4]     - ARB_LOST                                                 */
                                         /*     [5]     - IDLE                                                     */
                                         /*     [6]     - BUS_BUSY                                                 */
                                         /*     [7]     - reserved                                                 */
    };                                   /*                                                                        */
    __RW    uint32_t  BUF;               /*  !< Offset: 0x008    I2C Master Buffer data                            */
    __RW    uint32_t  TP;                /*  !< Offset: 0x00C    I2C Master Timer Period Register                  */
    __RW    uint32_t  SCL_LP;            /*  !< Offset: 0x010    I2C Master SCL Low Period.                        */
    __RW    uint32_t  SCL_HP;            /*  !< Offset: 0x014    I2C Master SCL High Period.                       */
    __RW    uint32_t  DATA_SETUP_TIME;   /*  !< Offset: 0x018    I2C Master SDA setup time                         */
    __RW    uint32_t  INT;               /*  !< Offset: 0x01C    I2C Master Interrupt Control                      */
                                         /*     [0]     - ENABLE    Write 1 to Enable INT. Write 0 to disable INT. */
                                         /*     [1]     - FLAG      Write 1 to Clean                               */
    __WO     uint32_t  IO_SEL;           /*  !< Offset: 0x020                                                      */
                                         /*     [0]     - SEL                                                      */
} I2CM_Type;

/* I2CM CTRL Register Definitions */

#define I2CM_SLAVE_ADDR_RS_Pos      0
#define I2CM_SLAVE_ADDR_RS_Msk      (0x1ul<<I2CM_SLAVE_ADDR_RS_Pos)

#define I2CM_SLAVE_ADDR_ADDR_Pos    1
#define I2CM_SLAVE_ADDR_ADDR_Msk    (0x7Ful<<I2CM_SLAVE_ADDR_Pos)

#define I2CM_CTRL_RUN_Pos           0
#define I2CM_CTRL_RUN_Msk           (0x1ul<<I2CM_CTRL_RUN_Pos)

#define I2CM_CTRL_START_Pos         1
#define I2CM_CTRL_START_Msk         (0x1ul<<I2CM_CTRL_START_Pos)

#define I2CM_CTRL_STOP_Pos          2
#define I2CM_CTRL_STOP_Msk          (0x1ul<<I2CM_CTRL_STOP_Pos)

#define I2CM_CTRL_ACK_Pos           3
#define I2CM_CTRL_ACK_Msk           (0x1ul<<I2CM_CTRL_ACK_Pos)

#define I2CM_CTRL_HS_Pos            4
#define I2CM_CTRL_HS_Msk            (0x1ul<<I2CM_CTRL_HS_Pos)

#define I2CM_CTRL_ADDR_Pos          5
#define I2CM_CTRL_ADDR_Msk          (0x1ul<<I2CM_CTRL_ADDR_Pos)

#define I2CM_CTRL_SLRST_Pos         6
#define I2CM_CTRL_SLRST_Msk         (0x1ul<<I2CM_CTRL_SLRST_Pos)

#define I2CM_CTRL_RSTB_Pos          7
#define I2CM_CTRL_RSTB_Msk          (0x1ul<<I2CM_CTRL_RSTB_Pos)

#define I2CM_STATUS_BUSY_Pos        0
#define I2CM_STATUS_BUSY_Msk        (0x1ul<<I2CM_STATUS_BUSY_Pos)

#define I2CM_STATUS_ERROR_Pos       1
#define I2CM_STATUS_ERROR_Msk       (0x1ul<<I2CM_STATUS_ERROR_Pos)

#define I2CM_STATUS_ADDR_ACK_Pos    2
#define I2CM_STATUS_ADDR_ACK_Msk    (0x1ul<<I2CM_STATUS_ADDR_ACK_Pos)

#define I2CM_STATUS_DATA_ACK_Pos    3
#define I2CM_STATUS_DATA_ACK_Msk    (0x1ul<<I2CM_STATUS_DATA_ACK_Pos)

#define I2CM_STATUS_ARB_LOST_Pos    4
#define I2CM_STATUS_ARB_LOST_Msk    (0x1ul<<I2CM_STATUS_ARB_LOST_Pos)

#define I2CM_STATUS_IDLE_Pos        5
#define I2CM_STATUS_IDLE_Msk        (0x1ul<<I2CM_STATUS_IDLE_Pos)

#define I2CM_STATUS_BUS_BUSY_Pos    6
#define I2CM_STATUS_BUS_BUSY_Msk    (0x1ul<<I2CM_STATUS_BUS_BUSY_Pos)

#define I2CM_BUF_Pos                0
#define I2CM_BUF_Msk                (0xFFul<<I2CM_BUF_Pos)

#define I2CM_TP_Pos                 0
#define I2CM_TP_Msk                 (0x7Ful<<I2CM_TP_Pos)

#define I2CM_SCL_LOW_Pos            0
#define I2CM_SCL_LOW_Msk            (0xFul<<I2CM_SCL_LOW_Pos)

#define I2CM_SCL_HIGH_Pos           0
#define I2CM_SCL_HIGH_Msk           (0xFul<<I2CM_SCL_HIGH_Pos)

#define I2CM_DATA_SETUP_TIME_Pos    0
#define I2CM_DATA_SETUP_TIME_Msk    (0xFul<<I2CM_DATA_SETUP_TIME_Pos)

#define I2CM_INT_ENABLE_Pos         0
#define I2CM_INT_ENABLE_Msk         (0x1ul<<I2CM_INT_ENABLE_Pos)

#define I2CM_INT_FLAG_Pos           1
#define I2CM_INT_FLAG_Msk           (0x1ul<<I2CM_INT_FLAG_Pos)

#define I2CM_IO_SEL_Pos             0
#define I2CM_IO_SEL_Msk             (0x1ul<<I2CM_IO_SEL_Pos)

/*@}*/ /* end of group  I2CM */



/*------------------------------ I2CS Controller ------------------------------*/
/** @addtogroup I2CS I2C Slave
    Memory Mapped Structure for I2C Slave
    @{
*/

typedef struct
{
    __RW    uint32_t  ADDR;             /* !< Offset: 0x000    I2C Slave Address                 */
    union {                             /*                                                       */
        __WO     uint32_t  CTRL;        /* !< Offset: 0x004    I2C Slave Control                 */
                                        /*      [2]     - SENDFINCLR    Write 1 to Clean SENDFIN */
                                        /*      [3]     - RECFINCLR     Write 1 to Clean RECFIN  */
                                        /*      [6]     - DA            Device Active            */
                                        /*      [7]     - RSTB          I2CS reset bit           */
        __RO     uint32_t  STATUS;      /* !< Offset: 0x004    I2C Slave Status                  */
                                        /*      [0]     - RREQ          Read BUF to Clean        */
                                        /*      [1]     - TREQ          Write BUF to Clean       */
                                        /*      [2]     - SENDFIN       Send Finish              */
                                        /*      [3]     - RECFIN        Receive Finish           */
                                        /*      [4]     - BUSACTIVE     Bus actived              */
                                        /*      [6]     - DA            Device Actived           */
    };                                  /*                                                       */
    __RW    uint32_t  BUF;              /* !< Offset: 0x008    I2C Slave Data Buffer             */
    __RW    uint32_t  ADDR10BITS;       /* !< Offset: 0x00C    I2C Slave Address 10bits extern   */
    __RW    uint32_t  INT;              /* !< Offset: 0x010    I2C Slave Interrupt               */

} I2CS_Type;

/* I2CM CTRL Register Definitions */

#define I2CS_ADDR_Pos                   0
#define I2CS_ADDR_Msk                   (0x7Ful<<I2CS_ADDR_Pos)
                                        
#define I2CS_CTRL_SENDFINCLR_Pos        2
#define I2CS_CTRL_SENDFINCLR_Msk        (0x1ul<<I2CS_CTRL_SENDFINCLR_Pos)
                                        
#define I2CS_CTRL_RECFINCLR_Pos         3
#define I2CS_CTRL_RECFINCLR_Msk         (0x1ul<<I2CS_CTRL_RECFINCLR_Pos)
                                        
#define I2CS_CTRL_DA_Pos                6
#define I2CS_CTRL_DA_Msk                (0x1ul<<I2CS_CTRL_DA_Pos)
                                        
#define I2CS_CTRL_RSTB_Pos              7
#define I2CS_CTRL_RSTB_Msk              (0x1ul<<I2CS_CTRL_RSTB_Pos)
                                        
#define I2CS_STATUS_RREQ_Pos            0
#define I2CS_STATUS_RREQ_Msk            (0x1ul<<I2CS_STATUS_RREQ_Pos)
                                        
#define I2CS_STATUS_TREQ_Pos            1
#define I2CS_STATUS_TREQ_Msk            (0x1ul<<I2CS_STATUS_TREQ_Pos)
                                        
#define I2CS_STATUS_SENDFIN_Pos         2
#define I2CS_STATUS_SENDFIN_Msk         (0x1ul<<I2CS_STATUS_SENDFIN_Pos)
                                        
#define I2CS_STATUS_RECFIN_Pos          3
#define I2CS_STATUS_RECFIN_Msk          (0x1ul<<I2CS_STATUS_RECFIN_Pos)
                                        
#define I2CS_STATUS_BUSACTIVE_Pos       4
#define I2CS_STATUS_BUSACTIVE_Msk       (0x1ul<<I2CS_STATUS_BUSACTIVE_Pos)
                                        
#define I2CS_STATUS_DA_Pos              6
#define I2CS_STATUS_DA_Msk              (0x1ul<<I2CS_STATUS_DA_Pos)
                                        
#define I2CS_BUF_Pos                    0
#define I2CS_BUF_Msk                    (0xFFul<<I2CS_BUF_Pos)
                                        
#define I2CS_ADDR10BITS_A9A8A7_Pos      0
#define I2CS_ADDR10BITS_A9A8A7_Msk      (0x7ul<<I2CS_ADDR10BITS_A9A8A7_Pos)
                                        
#define I2CS_ADDR10BITS_EN_Pos          3
#define I2CS_ADDR10BITS_EN_Msk          (0x1ul<<I2CS_ADDR10BITS_EN_Pos)
                                        
#define I2CS_INT_ENABLE_Pos             0
#define I2CS_INT_ENABLE_Msk             (0x1ul<<I2CS_INT_ENABLE_Pos)
                                        
#define I2CS_INT_FLAG_Pos               1
#define I2CS_INT_FLAG_Msk               (0x1ul<<I2CS_INT_FLAG_Pos)

/*@}*/ /* end of group  I2CS */

/*------------------------------ PWM Controller ------------------------------*/
/** @addtogroup PWM Controller
    Memory Mapped Structure for PWM
    @{
*/

typedef struct
{
    __RW    uint32_t    CTRL;       /* !< PWM control register                                              */
                                    /*      BITS[0:2] - Prescal by power(2, BITS[0:2])                      */
                                    /*      BITS[3]   - clock source select. 0=system clock, 1=RTC or IRC   */
                                    /*      BITS[7]   - Enable PWM                                          */
    __RW    uint32_t    HIGH_LOW;   /* !< PWM set high/low register                                         */
                                    /*      BITS[0:7] - Set LOW width by 256-LOW                            */
                                    /*      BITS[8:16]- Set HIGH wdith by 256-HIGH                          */
                                    /*      The HIGH must large then LOW.                                   */
} PWM_Type;

/* PWM CTRL Register Definitions */

#define PWM_CTRL_PRESCAL_Pos        0
#define PWM_CTRL_PRESCAL_Msk        (0x7ul << PWM_CTRL_PRESCAL_Pos)

#define PWM_CTRL_CKS_Pos            3
#define PWM_CTRL_CKS_Msk            (0x1ul << PWM_CTRL_CKS_Pos)

#define PWM_CTRL_EN_Pos             7
#define PWM_CTRL_EN_Msk             (0x1ul << PWM_CTRL_EN_Pos)

#define PWM_HIGH_LOW_LOW_Pos        0
#define PWM_HIGH_LOW_LOW_Msk        (0xFFul << PWM_HIGH_LOW_LOW_Pos)

#define PWM_HIGH_LOW_HIGH_Pos       8
#define PWM_HIGH_LOW_HIGH_Msk       (0xFFul << PWM_HIGH_LOW_HIGH_Pos)

/*@}*/ /* end of group  PWM */

/*------------------------------ ADC 12BIT Controller ------------------------------*/
/** @addtogroup ADC 12BIT  Controller
    Memory Mapped Structure for ADC 12BIT
    @{
*/

typedef struct
{
        __RW   uint32_t  CTRL;              /* !< Offset: 0x000 12-bit ADC Control Register          */
        __RO   uint32_t  ADC;               /* !< Offset: 0x004 12-bit ADC Register                  */
        union {                             /*                                                       */
            __RO   uint32_t  INTSTATE;      /* !< Offset: 0x008 12-bit ADC Interrupt State Register  */
            __WO   uint32_t  INTCLR;        /* !< Offset: 0x008 12-bit ADC Interrupt clear Register  */
        };
} ADC12B_Type;

/*@}*/ /* end of group  ADC 12BIT  */

/*------------------------------ DEVICE Controller ------------------------------*/
/** @addtogroup DEVICE  Controller
    Memory Mapped Structure for DEVICE
    @{
*/

typedef struct
{
        __RO    uint32_t    DID;    /* !< Offset: 0x000 Device Register */
} DEVICE_Type;

/*@}*/ /* end of group DEVICE  */

/******************************************************************************/
/*                         Peripheral memory map                              */
/******************************************************************************/
/** @addtogroup PERIPHERAL_BASE Peripheral Memory Base
  Memory Mapped Structure for Series Peripheral
  @{
 */

/* Peripheral Main_MAP base address */
#define TIMER_BASE                     (      ( uint32_t )        0x40000000 )
#define DUALTIMER_BASE                 (      ( uint32_t )        0x40002000 )
#define UART_BASE                      (      ( uint32_t )        0x40004000 )
#define WATCHDOG_BASE                  (      ( uint32_t )        0x40008000 )
#define GPIO_BASE                      (      ( uint32_t )        0x40010000 )
#define SYSCTRL_BASE                   (      ( uint32_t )        0x4001F000 )
#define FLASH_BASE                     (      ( uint32_t )        0x4001F100 )
#define POWER_BASE                     (      ( uint32_t )        0x50000000 )
#define RADIO_BASE                     (      ( uint32_t )        0x50001000 )
#define SPI_BASE                       (      ( uint32_t )        0x50002000 )
#define I2C_BASE                       (      ( uint32_t )        0x50003000 )
#define PWM_BASE                       (      ( uint32_t )        0x50004000 )
#define ADC12B_BASE                    (      ( uint32_t )        0x50008000 )
#define DEVICE_BASE                    (      ( uint32_t )        0x5000F000 )

/* Peripheral memory map */
#define TIMER0_BASE                    (      TIMER_BASE        + 0x00000000 )
#define TIMER1_BASE                    (      TIMER_BASE        + 0x00001000 )
#define DUALTIMER1_BASE                (      DUALTIMER_BASE    + 0x00000000 )
#define DUALTIMER2_BASE                (      DUALTIMER_BASE    + 0x00000020 )
#define GPIO0_BASE                     (      GPIO_BASE         + 0x00000000 )
#define GPIO1_BASE                     (      GPIO_BASE         + 0x00001000 )
#define UART0_BASE                     (      UART_BASE         + 0x00000000 )
#define UART1_BASE                     (      UART_BASE         + 0x00001000 )
#define UART2_BASE                     (      UART_BASE         + 0x00002000 )
#define I2CM_BASE                      (      I2C_BASE          + 0x00000000 )
#define I2CS_BASE                      (      I2C_BASE          + 0x00000800 )
#define PWM0_BASE                      (      PWM_BASE          + 0x00000000 )
#define PWM1_BASE                      (      PWM_BASE          + 0x00000100 )
#define PWM2_BASE                      (      PWM_BASE          + 0x00000200 )
#define PWM3_BASE                      (      PWM_BASE          + 0x00000300 )

/**@}*/ /* PERIPHERAL */

/******************************************************************************/
/*                         Peripheral declaration                             */
/******************************************************************************/

/** @addtogroup PMODULE Peripheral Pointer
  The Declaration of Peripheral Pointer
  @{
 */

#define TIMER0                     ( (TIMER_Type     *)  TIMER0_BASE     )
#define TIMER1                     ( (TIMER_Type     *)  TIMER1_BASE     )
#define DUALTIMER1                 ( (DUALTIMER_Type *)  DUALTIMER1_BASE )
#define DUALTIMER2                 ( (DUALTIMER_Type *)  DUALTIMER2_BASE )
#define UART0                      ( (UART_Type      *)  UART0_BASE      )
#define UART1                      ( (UART_Type      *)  UART1_BASE      )
#define UART2                      ( (UART_Type      *)  UART2_BASE      )
#define WATCHDOG                   ( (WATCHDOG_Type  *)  WATCHDOG_BASE   )
#define GPIO0                      ( (GPIO_Type      *)  GPIO0_BASE      )
#define GPIO1                      ( (GPIO_Type      *)  GPIO1_BASE      )
#define SYSCTRL                    ( (SYSCON_Type    *)  SYSCTRL_BASE    )
#define FLASH                      ( (FLASH_Type     *)  FLASH_BASE      )
#define POWER                      ( (POWER_Type     *)  POWER_BASE      )
#define RADIO                      ( (RADIO_Type     *)  RADIO_BASE      )
#define SPI                        ( (SPI_Type       *)  SPI_BASE        )
#define I2CM                       ( (I2CM_Type      *)  I2CM_BASE       )
#define I2CS                       ( (I2CS_Type      *)  I2CS_BASE       )
#define PWM0                       ( (PWM_Type       *)  PWM0_BASE       )
#define PWM1                       ( (PWM_Type       *)  PWM1_BASE       )
#define PWM2                       ( (PWM_Type       *)  PWM2_BASE       )
#define PWM3                       ( (PWM_Type       *)  PWM3_BASE       )
#define ADC12B                     ( (ADC12B_Type    *)  ADC12B_BASE     )
#define DID                        ( (DEVICE_Type    *)  DEVICE_BASE     )

/**@}*/ /* end of group PMODULE */



#endif
