/*--------------------------------------------------------------------------*/
/* A8137.H                                                                  */
/*                                                                          */
/* Header file for A8107 RF SoC microcontroller.                            */
/* Copyright (c) 2014 AMICCOM Electronics Corp.                             */
/*                                                                          */
/* All rights reserved.                                                     */
/*--------------------------------------------------------------------------*/
#ifndef __A8137M_H__
#define __A8137M_H__

#include "define.h"

extern uint32_t SystemFrequency;
extern uint32_t SystemCoreClock;

typedef enum IRQn
{
/******  Cortex-M0 Processor Exceptions Numbers ***************************************************/

/* ToDo: use this Cortex interrupt numbers if your device is a CORTEX-M0 device                   */
    NonMaskableInt_IRQn           = -14,      /*!<  2 Cortex-M0 Non Maskable Interrupt            */
    HardFault_IRQn                = -13,      /*!<  3 Cortex-M0 Hard Fault Interrupt              */
    SVCall_IRQn                   = -5,       /*!< 11 Cortex-M0 SV Call Interrupt                 */
    PendSV_IRQn                   = -2,       /*!< 14 Cortex-M0 Pend SV Interrupt                 */
    SysTick_IRQn                  = -1,       /*!< 15 Cortex-M0 System Tick Interrupt             */

/******  CMSDK Specific Interrupt Numbers *********************************************************/        
    UART0_IRQn                    = 1,       /*!< UART 0 Interrupt                                */
    SLEEPTIME0_IRQn               = 2,       /*!< SLEEP TIMER 0 Interrupt                         */
    RADIO_IRQn                    = 3,       /*!< RADIO Interrupt                                 */
		UART2_IRQn                    = 5,       /*!< UART 0 Interrupt                                */
    PORT0_ALL_IRQn                = 6,       /*!< Port 1 combined Interrupt                       */    
    TIMER0_IRQn                   = 8,       /*!< TIMER 0 Interrupt                               */
    TIMER1_IRQn                   = 9,       /*!< TIMER 1 Interrupt                               */
    DUALTIMER_IRQn                = 10,      /*!< Dual Timer Interrupt                            */
    CHARGE_IRQn                   = 11,      /*!< CHARGE Interrupt                                */
    UART1_IRQn                    = 13,      /*!< UART 1 Interrupt                                */       
    SPI_IRQn                      = 16,      /*!< SPI Interrupt                                   */
    I2C_IRQn                      = 17,      /*!< I2C Interrupt                                   */
    RTC_IRQn                      = 18,      /*!< RTC Interrupt                                   */
    CODEC_IRQn                    = 19,      /*!< CODEC Interrupt                                 */
    AES_CCM_IRQn                  = 20,      /*!< AES / CCM Interrupt                             */
    ADC12B_IRQn                   = 21,      /*!< 12Bit ADC Interrupt                             */
    RCADC_IRQn                    = 22,      /*!< RCADC Interrupt                                 */
    USB_IRQn                      = 23,      /*!< USB Interrupt                                   */
    SLEEPTIMER_IRQn               = 24,      /*!< SLEEP TIMER 0 Interrupt                         */
    EXT_IRQn                      = 31,
} IRQn_Type;


#if defined ( __CC_ARM   )
#pragma anon_unions
#endif

typedef struct {
    __RO   Uint8   RESERVED0[0x010-0x000];
    __RW   Uint32  CTRL;
    __RW   Uint32  LOAD;
    __RW   Uint32  VAL;
    __RW   Uint32  CAILB;
    __RO   Uint8   RESERVED1[0x100-0x01C-4];
    __RW   Uint32  SETENA;             // Interrupt enable set register
    __RO   Uint8   RESERVED2[0x180-0x100-4];
    __RW   Uint32  CLRENA;             // Interrupt enable clear register
    __RO   Uint8   RESERVED3[0x200-0x180-4];
    __RW   Uint32  SETPEND;
    __RO   Uint8   RESERVED4[0x280-0x200-4];
    __RW   Uint32  CLRPEND;
    __RO   Uint8   RESERVED5[0x400-0x280-4];
    __RW   Uint32  IPR0;
    __RW   Uint32  IPR1;
    __RW   Uint32  IPR2;
    __RW   Uint32  IPR3;
    __RW   Uint32  IPR4;
    __RW   Uint32  IPR5;
    __RW   Uint32  IPR6;
    __RW   Uint32  IPR7;
} SYSTEM_Type;

typedef struct
{
		__RW   Uint32 ISER[1];                 /*!< Offset: 0x000 (R/W)  Interrupt Set Enable Register           */
				   Uint32 RESERVED0[31];
		__RW   Uint32 ICER[1];                 /*!< Offset: 0x080 (R/W)  Interrupt Clear Enable Register          */
				   Uint32 RSERVED1[31];
		__RW   Uint32 ISPR[1];                 /*!< Offset: 0x100 (R/W)  Interrupt Set Pending Register           */
				   Uint32 RESERVED2[31];
		__RW   Uint32 ICPR[1];                 /*!< Offset: 0x180 (R/W)  Interrupt Clear Pending Register         */
				   Uint32 RESERVED3[31];
				   Uint32 RESERVED4[64];
		__RW   Uint32 IP[8];                   /*!< Offset: 0x300 (R/W)  Interrupt Priority Register              */
}  NVIC_Type;

typedef struct
{
		__RW   Uint32  CTRL;          /*!< Offset: 0x000 Control Register (R/W) */
		__RW   Uint32  VALUE;         /*!< Offset: 0x004 Current Value Register (R/W) */
		__RW   Uint32  RELOAD;        /*!< Offset: 0x008 Reload Value Register  (R/W) */
		union {
		__RO   Uint32  INTSTATUS;     /*!< Offset: 0x00C Interrupt Status Register (R/ ) */
		__WO   Uint32  INTCLR;      /*!< Offset: 0x00C Interrupt Clear Register ( /W) */
		};

} TIMER_Type;

typedef struct
{
  __RW Uint32 LOAD;    // <h> Timer Load </h>
  __RO Uint32 VALUE;   // <h> Timer Counter Current Value <r></h>
  __RW Uint32 CTRL; // <h> Timer Control
                              //   <o.7> TimerEn: Timer Enable
                              //   <o.6> TimerMode: Timer Mode
                              //     <0=> Freerunning-mode
                              //     <1=> Periodic mode
                              //   <o.5> IntEnable: Interrupt Enable
                              //   <o.2..3> TimerPre: Timer Prescale
                              //     <0=> / 1
                              //     <1=> / 16
                              //     <2=> / 256
                              //     <3=> Undefined!
                              //   <o.1> TimerSize: Timer Size
                              //     <0=> 16-bit counter
                              //     <1=> 32-bit counter
                              //   <o.0> OneShot: One-shoot mode
                              //     <0=> Wrapping mode
                              //     <1=> One-shot mode
                              // </h>
  __WO  Uint32 INTCLR;  // <h> Timer Interrupt Clear <w></h>
  __RO  Uint32 RIS;     // <h> Timer Raw Interrupt Status <r></h>
  __RO  Uint32 MIS;     // <h> Timer Masked Interrupt Status <r></h>
  __RW  Uint32 BGLOAD;  // <h> Background Load Register </h>
} DUALTIMER_Type;

typedef struct
{
		__RW   Uint32  DATA;          /*!< Offset: 0x000 Data Register    (R/W) */
		__RW   Uint32  STATE;         /*!< Offset: 0x004 Status Register  (R/W) */
		__RW   Uint32  CTRL;          /*!< Offset: 0x008 Control Register (R/W) */
		union {
			__RO   Uint32  INTSTATUS;     /*!< Offset: 0x00C Interrupt Status Register (R/ ) */
			__WO   Uint32  INTCLR;      /*!< Offset: 0x00C Interrupt Clear Register ( /W) */
		};
		__RW   Uint32  BAUDDIV;       /*!< Offset: 0x010 Baudrate Divider Register (R/W) */

} UART_Type;

typedef struct
{

		__RW   Uint32  LOAD;          // <h> Watchdog Load Register </h>
		__RO   Uint32  VALUE;         // <h> Watchdog Value Register </h>
		__RW   Uint32  CTRL;          // <h> Watchdog Control Register
																		 //   <o.1>    RESEN: Reset enable
																		 //   <o.0>    INTEN: Interrupt enable
																		 // </h>
		__WO   Uint32  INTCLR;        // <h> Watchdog Clear Interrupt Register </h>
		__RO   Uint32  RAWINTSTAT;    // <h> Watchdog Raw Interrupt Status Register </h>
		__RO   Uint32  MASKINTSTAT;   // <h> Watchdog Interrupt Status Register </h>
					 Uint32  WDT_RESERVED0[762];
		__RW   Uint32  LOCK;          // <h> Watchdog Lock Register </h>
					 Uint32  WDT_RESERVED1[191];
		__RW   Uint32  ITCR;          // <h> Watchdog Integration Test Control Register </h>
		__WO   Uint32  ITOP;          // <h> Watchdog Integration Test Output Set Register </h>
} WDT_Type;

typedef struct {
    union
    {
        __RW    Uint32  DATA;               // 0x000
        struct
        {
            __RW Uint32  P00     :  1;               /*!< Pn.0 */
            __RW Uint32  P01     :  1;               /*!< Pn.1 */
            __RW Uint32  P02     :  1;               /*!< Pn.2 */
            __RW Uint32  P03     :  1;               /*!< Pn.3 */
            __RW Uint32  P04     :  1;               /*!< Pn.4 */
            __RW Uint32  P05     :  1;               /*!< Pn.5 */
            __RW Uint32  P06     :  1;               /*!< Pn.6 */
            __RW Uint32  P07     :  1;               /*!< Pn.7 */
            __RW Uint32  P08     :  1;               /*!< Pn.8 */
            __RW Uint32  P09     :  1;               /*!< Pn.9 */
            __RW Uint32  P10     :  1;               /*!< Pn.10 */
            __RW Uint32  P11     :  1;               /*!< Pn.11 */
            __RW Uint32  P12     :  1;               /*!< Pn.12 */
            __RW Uint32  P13     :  1;               /*!< Pn.13 */
            __RW Uint32  P14     :  1;               /*!< Pn.14 */
            __RW Uint32  P15     :  1;               /*!< Pn.15 */
            __RW Uint32  P16     :  1;               /*!< Pn.16 */
            __RW Uint32  P17     :  1;               /*!< Pn.17 */
            __RW Uint32  P18     :  1;               /*!< Pn.18 */
            __RW Uint32  P19     :  1;               /*!< Pn.19 */
            __RW Uint32  P20     :  1;               /*!< Pn.20 */
            __RW Uint32  P21     :  1;               /*!< Pn.21 */
            __RW Uint32  P22     :  1;               /*!< Pn.22 */
            __RW Uint32  P23     :  1;               /*!< Pn.23 */
            __RW Uint32  P24     :  1;               /*!< Pn.24 */
            __RW Uint32  P25     :  1;               /*!< Pn.25 */
            __RW Uint32  P26     :  1;               /*!< Pn.26 */
            __RW Uint32  P27     :  1;               /*!< Pn.27 */
            __RW Uint32  P28     :  1;               /*!< Pn.28 */
            __RW Uint32  P29     :  1;               /*!< Pn.29 */
            __RW Uint32  P30     :  1;               /*!< Pn.30 */
            __RW Uint32  P31     :  1;               /*!< Pn.31 */
        } data;
    };
    union
    {
        __RW    Uint32  DATAOUT;            // 0x004
        struct
        {
            __RW Uint32  P00     :  1;               /*!< Pn.0 */
            __RW Uint32  P01     :  1;               /*!< Pn.1 */
            __RW Uint32  P02     :  1;               /*!< Pn.2 */
            __RW Uint32  P03     :  1;               /*!< Pn.3 */
            __RW Uint32  P04     :  1;               /*!< Pn.4 */
            __RW Uint32  P05     :  1;               /*!< Pn.5 */
            __RW Uint32  P06     :  1;               /*!< Pn.6 */
            __RW Uint32  P07     :  1;               /*!< Pn.7 */
            __RW Uint32  P08     :  1;               /*!< Pn.8 */
            __RW Uint32  P09     :  1;               /*!< Pn.9 */
            __RW Uint32  P10     :  1;               /*!< Pn.10 */
            __RW Uint32  P11     :  1;               /*!< Pn.11 */
            __RW Uint32  P12     :  1;               /*!< Pn.12 */
            __RW Uint32  P13     :  1;               /*!< Pn.13 */
            __RW Uint32  P14     :  1;               /*!< Pn.14 */
            __RW Uint32  P15     :  1;               /*!< Pn.15 */
            __RW Uint32  P16     :  1;               /*!< Pn.16 */
            __RW Uint32  P17     :  1;               /*!< Pn.17 */
            __RW Uint32  P18     :  1;               /*!< Pn.18 */
            __RW Uint32  P19     :  1;               /*!< Pn.19 */
            __RW Uint32  P20     :  1;               /*!< Pn.20 */
            __RW Uint32  P21     :  1;               /*!< Pn.21 */
            __RW Uint32  P22     :  1;               /*!< Pn.22 */
            __RW Uint32  P23     :  1;               /*!< Pn.23 */
            __RW Uint32  P24     :  1;               /*!< Pn.24 */
            __RW Uint32  P25     :  1;               /*!< Pn.25 */
            __RW Uint32  P26     :  1;               /*!< Pn.26 */
            __RW Uint32  P27     :  1;               /*!< Pn.27 */
            __RW Uint32  P28     :  1;               /*!< Pn.28 */
            __RW Uint32  P29     :  1;               /*!< Pn.29 */
            __RW Uint32  P30     :  1;               /*!< Pn.30 */
            __RW Uint32  P31     :  1;               /*!< Pn.31 */
        } dataout;
    };
    union
    {
        __RW    Uint32  PULLHIGHSET;                   // 0x008
        struct
        {
            __RW Uint32  P00     :  1;               /*!< Pn.0 */
            __RW Uint32  P01     :  1;               /*!< Pn.1 */
            __RW Uint32  P02     :  1;               /*!< Pn.2 */
            __RW Uint32  P03     :  1;               /*!< Pn.3 */
            __RW Uint32  P04     :  1;               /*!< Pn.4 */
            __RW Uint32  P05     :  1;               /*!< Pn.5 */
            __RW Uint32  P06     :  1;               /*!< Pn.6 */
            __RW Uint32  P07     :  1;               /*!< Pn.7 */
            __RW Uint32  P08     :  1;               /*!< Pn.8 */
            __RW Uint32  P09     :  1;               /*!< Pn.9 */
            __RW Uint32  P10     :  1;               /*!< Pn.10 */
            __RW Uint32  P11     :  1;               /*!< Pn.11 */
            __RW Uint32  P12     :  1;               /*!< Pn.12 */
            __RW Uint32  P13     :  1;               /*!< Pn.13 */
            __RW Uint32  P14     :  1;               /*!< Pn.14 */
            __RW Uint32  P15     :  1;               /*!< Pn.15 */
            __RW Uint32  P16     :  1;               /*!< Pn.16 */
            __RW Uint32  P17     :  1;               /*!< Pn.17 */
            __RW Uint32  P18     :  1;               /*!< Pn.18 */
            __RW Uint32  P19     :  1;               /*!< Pn.19 */
            __RW Uint32  P20     :  1;               /*!< Pn.20 */
            __RW Uint32  P21     :  1;               /*!< Pn.21 */
            __RW Uint32  P22     :  1;               /*!< Pn.22 */
            __RW Uint32  P23     :  1;               /*!< Pn.23 */
            __RW Uint32  P24     :  1;               /*!< Pn.24 */
            __RW Uint32  P25     :  1;               /*!< Pn.25 */
            __RW Uint32  P26     :  1;               /*!< Pn.26 */
            __RW Uint32  P27     :  1;               /*!< Pn.27 */
            __RW Uint32  P28     :  1;               /*!< Pn.28 */
            __RW Uint32  P29     :  1;               /*!< Pn.29 */
            __RW Uint32  P30     :  1;               /*!< Pn.30 */
            __RW Uint32  P31     :  1;               /*!< Pn.31 */
        } pun;        
    };
    union
    {
        __RW    Uint32  WAKEUPSET;                   // 0x00C
        struct
        {
            __RW Uint32  P00     :  1;               /*!< Pn.0 */
            __RW Uint32  P01     :  1;               /*!< Pn.1 */
            __RW Uint32  P02     :  1;               /*!< Pn.2 */
            __RW Uint32  P03     :  1;               /*!< Pn.3 */
            __RW Uint32  P04     :  1;               /*!< Pn.4 */
            __RW Uint32  P05     :  1;               /*!< Pn.5 */
            __RW Uint32  P06     :  1;               /*!< Pn.6 */
            __RW Uint32  P07     :  1;               /*!< Pn.7 */
            __RW Uint32  P08     :  1;               /*!< Pn.8 */
            __RW Uint32  P09     :  1;               /*!< Pn.9 */
            __RW Uint32  P10     :  1;               /*!< Pn.10 */
            __RW Uint32  P11     :  1;               /*!< Pn.11 */
            __RW Uint32  P12     :  1;               /*!< Pn.12 */
            __RW Uint32  P13     :  1;               /*!< Pn.13 */
            __RW Uint32  P14     :  1;               /*!< Pn.14 */
            __RW Uint32  P15     :  1;               /*!< Pn.15 */
            __RW Uint32  P16     :  1;               /*!< Pn.16 */
            __RW Uint32  P17     :  1;               /*!< Pn.17 */
            __RW Uint32  P18     :  1;               /*!< Pn.18 */
            __RW Uint32  P19     :  1;               /*!< Pn.19 */
            __RW Uint32  P20     :  1;               /*!< Pn.20 */
            __RW Uint32  P21     :  1;               /*!< Pn.21 */
            __RW Uint32  P22     :  1;               /*!< Pn.22 */
            __RW Uint32  P23     :  1;               /*!< Pn.23 */
            __RW Uint32  P24     :  1;               /*!< Pn.24 */
            __RW Uint32  P25     :  1;               /*!< Pn.25 */
            __RW Uint32  P26     :  1;               /*!< Pn.26 */
            __RW Uint32  P27     :  1;               /*!< Pn.27 */
            __RW Uint32  P28     :  1;               /*!< Pn.28 */
            __RW Uint32  P29     :  1;               /*!< Pn.29 */
            __RW Uint32  P30     :  1;               /*!< Pn.30 */
            __RW Uint32  P31     :  1;               /*!< Pn.31 */
        } wun;
    };
    __RW   Uint32  OUTENSET;           /*!< Offset: 0x010 OUTENSET   Register (R/ ) */
    __RW   Uint32  OUTENCLR;           /*!< Offset: 0x014 OUTENCLR   Register (R/ ) */
    __RW   Uint32  ALTFUNCSET;         /*!< Offset: 0x018 ALTFUNCSET Register (R/ ) */
    __RW   Uint32  ALTFUNCCLR;         /*!< Offset: 0x01C ALTFUNCCLR Register (R/ ) */
    __RW   Uint32  INTENSET;           /*!< Offset: 0x020 INTENSET   Register (R/ ) */
    __RW   Uint32  INTENCLR;           /*!< Offset: 0x024 INTENCLR   Register (R/ ) */
    __RW   Uint32  INTTYPESET;         /*!< Offset: 0x028 INTTYPESET Register (R/ ) */
    __RW   Uint32  INTTYPECLR;         /*!< Offset: 0x02C INTTYPECLR Register (R/ ) */
    __RW   Uint32  INTPOLSET;          /*!< Offset: 0x030 INTPOLSET  Register (R/ ) */
    __RW   Uint32  INTPOLCLR;          /*!< Offset: 0x034 INTPOLCLR  Register (R/ ) */
    union {
			__RO   Uint32  INTSTATUS;          /*!< Offset: 0x038 Interrupt Status Register (R/ ) */
			__WO   Uint32  INTCLR;           /*!< Offset: 0x038 Interrupt Clear Register ( /W) */
    };
} GPIO_Type;

typedef struct
{
	  __RW   Uint32  MODECTRL;           /*!< Offset: 0x000 Flash Mone Control Register (R/ ) */
	  __RW   Uint32  FLASHCTRL;          /*!< Offset: 0x004 Flash Control Register (R/ ) */
	  __RW   Uint32  IAPCTRL;            /*!< Offset: 0x008 Flash IAP Control Register (R/ ) */
	  __RW   Uint32  ADDRESS;            /*!< Offset: 0x00C Flash IAP Start Address Register (R/ ) */
	  __RW   Uint32  PASSWORD[2];        /*!< Offset: 0x010 - 0x014 Flash IAP Password Register (R/ ) */
	  __RW   Uint32  PASSWORDGOAL[2];    /*!< Offset: 0x018 - 0x01C Flash IAP Password Goal Register (R/ ) */
	         Uint32  FLASH_Reserved0[56];/*!< Offset: 0x020 - 0x00FC Reserved */
	  union {
			__RW   Uint32  DATA[32];           /*!< Offset: 0x100 - 0x17F Flash IAP Data Register (R/ ) */
			__RW   Uint8   data[128];
		};
	         Uint32  FLASH_Reserved1[32];/*!< Offset: 0x180 - 0x0200 Reserved */
	  __RW   Uint32  SECTPROECT;         /*!< Offset: 0x200 Flash IAP Sect Proect Register (R/ ) */
} FLASH_Type;


typedef struct
{
    __RW   Uint32  BATTERY;            /*!< Offset: 0x000 BATTERY Detect Register  (R/W) */
    __WO   Uint32  FLASHPOWERCTRL;     /*!< Offset: 0x004 Flash Power Control Register  (R/W) */
    union {
			__RW   Uint32  POWERCTRL1;       /*!< Offset: 0x008 Power Control I  Register (R/W) */
			struct
			{
				__RW   Uint8  PMCTRL;         
				       Uint8  POWERCTRL_RESERVED[3];
			}powerctrl1;
		};
	  __RW   Uint32  POWERCTRL2;         /*!< Offset: 0x00C Power Control II Register (R/W) */
           Uint32  RF_RESERVED0[4];    /*!< Offset: 0x010 - 0x01C Reserved */
    __RW   Uint32  CHARGECTRL;         /*!< Offset: 0x020 Charge Control  Register (R/W) */
           Uint32  RF_RESERVED1[7];    /*!< Offset: 0x024 - 0x03C Reserved */
    __RW   Uint32  RCCTRL1;            /*!< Offset: 0x040 RC Control I  Register (R/W) */
    __RW   Uint32  RCCTRL2;            /*!< Offset: 0x044 RC Control II Register (R/W) */
    __RW   Uint32  RCTARGET;           /*!< Offset: 0x048 RC Target Register (R/W) */       
           Uint32  RF_RESERVED2;       /*!< Offset: 0x04C Reserved */
    __RW   Uint32  XRCCTRL1;           /*!< Offset: 0x050 XRC Control I  Register (R/W) */
    __RW   Uint32  XRCCTRL2;           /*!< Offset: 0x054 XRC Control II Register (R/W) */
    __RW   Uint32  XRCTARGET;          /*!< Offset: 0x058 XRC Target Register (R/W) */       
} POWER_Type;

#define RF_FIFO_SIZE   256
typedef struct
{
    __WO   Uint32  RESET;              /*!< Offset: 0x000 RF_RESET Register  (R/W) */
    __RW   Uint32  STROBE;             /*!< Offset: 0x004 Strobe Command Register  (R/W) */
    __RW   Uint32  MODECTRL;           /*!< Offset: 0x008 Mode Control Register (R/W) */
           Uint32  RF_RESERVED0[1];    /*!< Offset: 0x00C Reserved */
    __RO   Uint32  STATUS;             /*!< Offset: 0x010 STATUS Register (R)  */
    __RW   Uint32  INTSTATE;           /*!< Offset: 0x014 RF Interrupt State Register (W/R)  */   
	
    union {
			__RW   Uint32  SYNC_ID32b[2];       /*!< Offset: 0x018 SYNC ID Register (R/W)  */
			__RW   Uint8   SYNC_ID8b[8];
    };
    __RW   Uint32  FIFOCTRL;           /*!< Offset: 0x020 FIFO Control Register (R/W)  */
    __RW   Uint32  DATARATE;           /*!< Offset: 0x024 Data Rate Register (R/W)  */    
		
    union {
			__RW   Uint32  RFGIO;            /*!< Offset: 0x028 RF GIO Register (R/W)  */    
			struct {
				__RW   Uint8  GPIO1;
				__RW   Uint8  GPIO2;
				__RW   Uint8  CKO;					
				       Uint8  RFGIO_Reserved;
			} rfgio;	       
		};
           Uint32  RF_RESERVED2[21];   /*!< Offset: 0x02C - 0x7C Reserved */
    __RW   Uint32  CALIBRATION;        /*!< Offset: 0x080 Calibration Register (R/W) */
    __RW   Uint32  IFCTRL;             /*!< Offset: 0x084 IF Control Register (R/W) */
    __RW   Uint32  VCOC;               /*!< Offset: 0x088 VCO Current Register (R/W) */
    __RW   Uint32  VCOBAND;            /*!< Offset: 0x08C VCO BAND Register (R/W) */
    __RW   Uint32  VCODEV1;            /*!< Offset: 0x090 VCO Deviation I  Register (R/W) */
    __RW   Uint32  VCODEV2;            /*!< Offset: 0x094 VCO Deviation II Register (R/W) */
           Uint32  RF_RESERVED3[10];   /*!< Offset: 0x098 - 0x0BC Reserved */
    __RW   Uint32  CHANNEL;            /*!< Offset: 0x0C0 Channel Register (R/W) */
    __RW   Uint32  FREQUENCY1;         /*!< Offset: 0x0C4 RF Frequency I Register (R/W) */
    __RW   Uint32  FREQUENCY2;         /*!< Offset: 0x0C8 RF Frequency II Register (R/W) */
    __RW   Uint32  CHGROUP;            /*!< Offset: 0x0CC Channel Group Register (R/W) */
           Uint32  RF_RESERVED4[12];   /*!< Offset: 0x0B0 - 0x0FC Reserved */
    __WO   Uint32  TXCTRL;             /*!< Offset: 0x100 TX Control Register (W) */
    __WO   Uint32  TXPOWER;            /*!< Offset: 0x104 TX Power Register (W) */
    __WO   Uint32  TXMODCTRL;          /*!< Offset: 0x108 TX Modulation Control Register (W) */
    __WO   Uint32  TXMOD;              /*!< Offset: 0x10C TX Modulation Register (W) */
           Uint32  RF_RESERVED5[12];   /*!< Offset: 0x110 - 0x13C Reserved */
    __RW   Uint32  RXCTRL;             /*!< Offset: 0x140 RX Control Register (R/W) */
    __RW   Uint32  RXGAIN1;            /*!< Offset: 0x144 RX Gain I  Register (R/W) */         
    __WO   Uint32  RXGAIN2;            /*!< Offset: 0x148 RX Gain II Register */
           Uint32  RF_RESERVED6[1];    /*!< Offset: 0x14C Reserved */
    __RW   Uint32  RXDEM1;             /*!< Offset: 0x150 RX Demodulation I  Register (R/W) */
    __RW   Uint32  RXDEM2;             /*!< Offset: 0x154 RX Demodulation II Register (R/W) */
           Uint32  RF_RESERVED7[10];   /*!< Offset: 0x158 - 0x17C Reserved */
    __WO   Uint32  CODE;               /*!< Offset: 0x180 CODE Register (W) */
    __WO   Uint32  WS;                 /*!< Offset: 0x184 WS Register (W) */
		__WO   Uint32  CRCPL;              /*!< Offset: 0x188 CRCPL Register (W) */		
		__WO   Uint32  CRCIV;              /*!< Offset: 0x18C CRCIV Register (W) */		
           Uint32  RF_RESERVED8[12];   /*!< Offset: 0x190 - 0x1BC Reserved */
    __RW   Uint32  DELAY;              /*!< Offset: 0x1C0 DELAY Register (R/W) */
    __RW   Uint32  CLOCKCTRL1;         /*!< Offset: 0x1C4 RF Clock Control I  Register (R/W) */
    __WO   Uint32  CLOCKCTRL2;         /*!< Offset: 0x1C8 RF Clock Control II Register (W) */
    __WO   Uint32  Reserved9[1];       /*!< Offset: 0x1CC Reserved */
    __WO   Uint32  CPC;                /*!< Offset: 0x1D0 Charge Pump Register (W) */
    __RW   Uint32  RFTEST1;            /*!< Offset: 0x1D4 RF Test I   Register (R/W) */
    __RW   Uint32  RFTEST2;            /*!< Offset: 0x1D8 RF Test II  Register (R/W) */
		__RW   Uint32  RFTEST3;            /*!< Offset: 0x1DC RF Test III Register (R/W) */
		__RW   Uint32  RFTEST4;            /*!< Offset: 0x1E0 RF Test IV  Register (R/W) */
		__RW   Uint32  RFTEST5;            /*!< Offset: 0x1E4 RF Test V   Register (R/W) */
           Uint32  RF_RESERVED10[6];   /*!< Offset: 0x1E0 - 0x1FC Reserved */
    __RW   Uint32  TimerWakeup;        /*!< Offset: 0x200 Timer Wake up Register (R/W) */
    __WO   Uint32  RBTO;               /*!< Offset: 0x204 RBTO Register (R/W) */
		__WO   Uint32  RBT;                /*!< Offset: 0x208 RBT Register (R/W) */
           Uint32  RF_RESERVED11[13];  /*!< Offset: 0x20C - 0x23C Reserved */
    __RW   Uint32  ADCCTRL;            /*!< Offset: 0x240 8-bit ADC Control Register (R/W) */
    __RW   Uint32  ADC;                /*!< Offset: 0x244 8-bit ADC Threshold Register (R/W) */
		__RW   Uint32  ADCCAL   ;          /*!< Offset: 0x244 8-bit ADC Calibration Register (R/W) */
           Uint32  RF_RESERVED12[45];  /*!< Offset: 0x248 - 0x2FC Reserved */
    __RW   Uint32  MODESEL;            /*!< Offset: 0x300 MODESEL Register (R/W) */
    __RW   Uint32  CSMACACTL;          /*!< Offset: 0x304 CSMA_CA Register (R/W) */    
		__WO   Uint32  ARTCTL;             /*!< Offset: 0x308 ART Register (W) */		
    __WO   Uint32  ACKCTL;             /*!< Offset: 0x30C ACK Register (R/W) */                            
    __RW   Uint32  LQICTL;             /*!< Offset: 0x310 LQI Register (W) */		
    __WO   Uint32  ADFCTL;             /*!< Offset: 0x314 ADFC Register (W) */
    __WO   Uint32  PID;                /*!< Offset: 0x318 PID Register (R/W) */
    __WO   Uint32  SADD;               /*!< Offset: 0x31C SADD Register (R/W) */
    __WO   Uint32  LADD[2];            /*!< Offset: 0x320 - 0x324 LADD Register (R/W) */		
		__RW   Uint32  PNG;                /*!< Offset: 0x328 PNG Register (R/W) */
           Uint32  RF_RESERVED13[53];  /*!< Offset: 0x32C - 0x3FC Reserved */
		union {			 
			__RW   Uint32  FIFO32b[RF_FIFO_SIZE / 4]; /*!< Offset: 0x400 - 0x4FF FIFO Register (W) */
			__RW   Uint32  FIFO8b[RF_FIFO_SIZE]; /*!< Offset: 0x400 - 0x4FF FIFO Register (W) */
		};
} RADIO_Type;

typedef struct
{ 
		__RW   Uint32  CTRL;               /*!< Offset: 0x000 SPI Control       Register  (R/W) */               			
		__RW   Uint32  STATUS;             /*!< Offset: 0x004 SPI Status        Register  (R/W) */
		__RW   Uint32  INTST;              /*!< Offset: 0x008 SPI INT Status    Register  (R/W) */
		__RW   Uint32  SSCTRL;             /*!< Offset: 0x00C SPI Slave Select Control Register  (R/W) */
		__RW   Uint32  TXFIFOSTATUS;       /*!< Offset: 0x010 TX FIFO Status  Register  (R/W) */
		__RW   Uint32  RXFIFOSTATUS;       /*!< Offset: 0x014 RX FIFO Status  Register  (R/W) */
		__RW   Uint32  TXFIFO;             /*!< Offset: 0x018 TX FIFO Register  (R/W) */
		__RW   Uint32  RXFIFO;             /*!< Offset: 0x01C RX FIFO Register  (R/W) */	
} SPI_Type;

typedef struct
{
		__RW   Uint32  ADDR;               /*!< Offset: 0x000 ADddress Register  (R/W) */               
		union {                            /*!< Offset: 0x004 Control  Register  (R/W) */
			__RW   Uint32  CTRL;
			__RW   Uint32  STATE;
		};
		__RW   Uint32  DATA;               /*!< Offset: 0x008 Data          Register  (R/W) */
		__RW   Uint32  TimerPeriod;        /*!< Offset: 0x00C TimerPeriod   Register  (R/W) */
		__RW   Uint32  SCLL;               /*!< Offset: 0x010 SCL Low Time  Register  (R/W) */
		__RW   Uint32  SCLH;               /*!< Offset: 0x014 SCL High Time Register  (R/W) */
		__RW   Uint32  DataSetupTime;      /*!< Offset: 0x018 DataSetupTime Register  (R/W) */
		__RW   Uint32  INTSTATE;           /*!< Offset: 0x01C I2CM Interrupt Register  (R/W) */
} I2CM_Type;

typedef struct
{		
		__RW   Uint32  I2C_Reserved0;      /*!< Offset: 0x000 ADddress Register  (R/W) */
		__RW   Uint32  ADDR;               /*!< Offset: 0x004 ADddress Register  (R/W) */
		union {                            /*!< Offset: 0x008 Control  Register  (R/W) */
			__WO   Uint32  CTRL;
			__RO   Uint32  STATE;
		};
		__RW   Uint32  DATA;               /*!< Offset: 0x00C Data          Register  (R/W) */					 
		__RW   Uint32  Address10Bits;      /*!< Offset: 0x010 Address10Bits Register  (R/W) */
		__RW   Uint32  INTSTATE;           /*!< Offset: 0x014 I2CS Interrupt Register  (R/W) */
} I2CS_Type;

typedef struct
{ 
		__RW   Uint32  CTRL;                /*!< Offset: 0x000 PWM CTRL Register  (R/W) */	
		union {
			__RW   Uint32  DUTY;              /*!< Offset: 0x0004 PWM Duty Register  (R/W) */
			struct
      {
				__RW Uint8  PWMxL;
				__RW Uint8  PWMxH;
      } duty;	
		};		
} PWM_Type;


typedef struct
{	
		__RW   Uint32  CTRL;                /*!< Offset: 0x000 12-bit ADC Control Register  (R/W) */
		__RO   Uint32  ADC;                 /*!< Offset: 0x004 12-bit ADC Register  (R) */	
		union {
			__RO   Uint32  INTSTATE;		      /*!< Offset: 0x008 12-bit ADC Interrupt State Register  (R) */		
			__WO   Uint32  INTCLR;            /*!< Offset: 0x008 12-bit ADC Interrupt clear Register  (R) */		
		};
} ADC12B_Type;

typedef struct
{
		__RO   Uint32  DID; 								/*!< Offset: 0x000 Device Register  (R/W) */		
} DEVICE_Type;

#define SYSTEM_BASE                    0xE000E000
#define NVIC_BASE                      (SYSTEM_BASE +  0x00000100)

#define TIMER_BASE                     0x40000000
#define DUALTIMER_BASE                 0x40002000
#define UART_BASE                      0x40004000
#define WDT_BASE                       0x40008000
#define GPIO_BASE                      0x40010000
#define FLASH_BASE                     0x4001F100
#define POWER_BASE                     0x50000000
#define RADIO_BASE                     0x50001000
#define SPI_BASE                       0x50002000
#define I2C_BASE                       0x50003000
#define PWM_BASE                       0x50004000
#define ADC12B_BASE                    0x50008000
#define DEVICE_BASE                    0x5000F000

#define TIMER0_BASE                    (TIMER_BASE + 0x00000000)
#define TIMER1_BASE                    (TIMER_BASE + 0x00001000)

#define DUALTIMER1_BASE                (DUALTIMER_BASE + 0x00000000)
#define DUALTIMER2_BASE                (DUALTIMER_BASE + 0x00000020)

#define UART0_BASE                     (UART_BASE + 0x00000000)
#define UART1_BASE                     (UART_BASE + 0x00001000)
#define UART2_BASE                     (UART_BASE + 0x00002000)

#define GPIO0_BASE                     (GPIO_BASE + 0x00000000)
#define GPIO1_BASE                     (GPIO_BASE + 0x00001000)

#define I2CM_BASE                      (I2C_BASE + 0x00000000)
#define I2CS_BASE                      (I2C_BASE + 0x00000800)

#define PWM0_BASE                      (PWM_BASE + 0x00000000)
#define PWM1_BASE                      (PWM_BASE + 0x00000100)
#define PWM2_BASE                      (PWM_BASE + 0x00000200)
#define PWM3_BASE                      (PWM_BASE + 0x00000300)
#define PWM4_BASE                      (PWM_BASE + 0x00000400)
#define PWM5_BASE                      (PWM_BASE + 0x00000500)
#define PWM6_BASE                      (PWM_BASE + 0x00000600)
#define PWM7_BASE                      (PWM_BASE + 0x00000700)


#define AMC_SYSTEM                     ((SYSTEM_Type       *)  SYSTEM_BASE)
#define AMC_NVIC                       ((NVIC_Type         *)  NVIC_BASE)

#define AMC_TIMER0                     ((TIMER_Type        *)  TIMER0_BASE)
#define AMC_TIMER1                     ((TIMER_Type        *)  TIMER1_BASE)
#define AMC_DUALTIMER1                 ((DUALTIMER_Type    *)  DUALTIMER1_BASE)
#define AMC_DUALTIMER2                 ((DUALTIMER_Type    *)  DUALTIMER2_BASE)
#define AMC_UART0                      ((UART_Type         *)  UART0_BASE)
#define AMC_UART1                      ((UART_Type         *)  UART1_BASE)
#define AMC_UART2                      ((UART_Type         *)  UART2_BASE)
#define AMC_WDT                        ((WDT_Type          *)  WDT_BASE)
#define AMC_GPIO0                      ((GPIO_Type         *)  GPIO0_BASE)
#define AMC_GPIO1                      ((GPIO_Type         *)  GPIO1_BASE)
#define AMC_FLASH                      ((FLASH_Type        *)  FLASH_BASE)
#define AMC_POWER                      ((POWER_Type        *)  POWER_BASE)
#define AMC_RADIO                      ((RADIO_Type        *)  RADIO_BASE)
#define AMC_SPI                        ((SPI_Type          *)  SPI_BASE)
#define AMC_I2CM                       ((I2CM_Type         *)  I2CM_BASE)
#define AMC_I2CS                       ((I2CS_Type         *)  I2CS_BASE)
#define AMC_PWM0                       ((PWM_Type          *)  PWM0_BASE)
#define AMC_PWM1                       ((PWM_Type          *)  PWM1_BASE)
#define AMC_PWM2                       ((PWM_Type          *)  PWM2_BASE)
#define AMC_PWM3                       ((PWM_Type          *)  PWM3_BASE)
#define AMC_PWM4                       ((PWM_Type          *)  PWM4_BASE)
#define AMC_PWM5                       ((PWM_Type          *)  PWM5_BASE)
#define AMC_PWM6                       ((PWM_Type          *)  PWM6_BASE)
#define AMC_PWM7                       ((PWM_Type          *)  PWM7_BASE)
#define AMC_ADC12B                     ((ADC12B_Type       *)  ADC12B_BASE)
#define AMC_DID                        ((DEVICE_Type       *)  DEVICE_BASE)


//--------------------------------------------------------------------------
// Strobe and Reset Command
//--------------------------------------------------------------------------
/* RF Strobe command */
#define CMD_SLEEP                       0x80    // SLEEP mode
#define CMD_IDLE                        0x90    // IDLE mode
#define CMD_STBY                        0xA0    // Standby mode
#define CMD_PLL                         0xB0    // PLL mode
#define CMD_RX                          0xC0    // RX mode
#define CMD_TX                          0xD0    // TX mode

/* RF Reset command */
#define RF_RST                          0x80
#define TXFIFOPOINT_RST                 0x40
#define RXFIFOPOINT_RST                 0x20
#define FIFODATA_RST                    0x10
#define BFC_RST                         0x08

#endif
