;/**************************************************************************//**
; * @file     startup_CMSDK_CM0.s
; * @brief    CMSIS Cortex-M0 Core Device Startup File for
; *           Device CMSDK_CM0
; * @version  V3.01
; * @date     06. March 2012
; *
; * @note
; * Copyright (C) 2012 ARM Limited. All rights reserved.
; *
; * @par
; * ARM Limited (ARM) is supplying this software for use with Cortex-M
; * processor based microcontrollers.  This file can be freely distributed
; * within development tools that are supporting such ARM based processors.
; *
; * @par
; * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
; * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
; * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
; * ARM SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR
; * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
; *
; ******************************************************************************/
;/*
;//-------- <<< Use Configuration Wizard in Context Menu >>> ------------------
;*/


; <h> Stack Configuration
;   <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Stack_Size      EQU     0x00000200

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp


; <h> Heap Configuration
;   <o>  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Heap_Size       EQU     0x00000100

                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit


                PRESERVE8
                THUMB


; Vector Table Mapped to Address 0 at Reset

                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors
                EXPORT  __Vectors_End
                EXPORT  __Vectors_Size

__Vectors       DCD     __initial_sp              ; Top of Stack
                DCD     Reset_Handler             ; Reset Handler
                DCD     NMI_Handler               ; NMI Handler
                DCD     HardFault_Handler         ; Hard Fault Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     SVC_Handler               ; SVCall Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     PendSV_Handler            ; PendSV Handler
                DCD     SysTick_Handler           ; SysTick Handler
                DCD     0                         ; Reserved
                DCD     UART0_Handler             ; UART 0 Handler
                DCD     SLEEPTIMER0_Handler       ; SLEEP TIMER 0 Handler
                DCD     RADIO_Handler             ; RADIO Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     PORT0_COMB_Handler        ; GPIO Port 0 Combined Handler
                DCD     0                         ; Reserved
                DCD     TIMER0_Handler            ; TIMER 0 handler
                DCD     TIMER1_Handler            ; TIMER 1 handler
                DCD     DUALTIMER_Handler         ; DDUAL TIMER handler
                DCD     CHARGE_Handler            ; CHARGE handler
                DCD     0                         ; Reserved
                DCD     UART1_Handler             ; UART 1 Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     SPI_Handler               ; SPI Handler
                DCD     I2C_Handler               ; I2C Handler
                DCD     RTC_Handler               ; RTC Handler
                DCD     CODEC_Handler             ; CODEC Handler
                DCD     AES_CCM_Handler           ; AES / CCM Handler
                DCD     ADC12B_Handler            ; 12 Bit ADC Handler
                DCD     RCADC_Handler             ; RCADC Handler
                DCD     USB_Handler               ; USB Handler
                DCD     SLEEPTIMER_Handler       ; SLEEP TIMER Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     EXT_Handler               ; External Handler
__Vectors_End

__Vectors_Size  EQU     __Vectors_End - __Vectors

                AREA    |.text|, CODE, READONLY


; Reset Handler

Reset_Handler   PROC
                EXPORT  Reset_Handler             [WEAK]
                IMPORT  SystemInit
                IMPORT  __main
                LDR     R0, =SystemInit
                BLX     R0
                LDR     R0, =__main
                BX      R0
                ENDP


; Dummy Exception Handlers (infinite loops which can be modified)

NMI_Handler     PROC
                EXPORT  NMI_Handler               [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                EXPORT  HardFault_Handler         [WEAK]
                B       .
                ENDP
SVC_Handler     PROC
                EXPORT  SVC_Handler               [WEAK]
                B       .
                ENDP
PendSV_Handler  PROC
                EXPORT  PendSV_Handler            [WEAK]
                B       .
                ENDP
SysTick_Handler PROC
               EXPORT  SysTick_Handler            [WEAK]
               B       .
               ENDP
Default_Handler PROC                
                EXPORT UART0_Handler              [WEAK]
                EXPORT SLEEPTIMER0_Handler        [WEAK]
                EXPORT RADIO_Handler              [WEAK]                
                EXPORT PORT0_COMB_Handler         [WEAK]                
                EXPORT TIMER0_Handler             [WEAK]
                EXPORT TIMER1_Handler             [WEAK]
                EXPORT DUALTIMER_Handler          [WEAK]
                EXPORT CHARGE_Handler             [WEAK]
				EXPORT UART1_Handler              [WEAK]						
                EXPORT SPI_Handler                [WEAK]
                EXPORT I2C_Handler                [WEAK]
				EXPORT RTC_Handler                [WEAK]	                               
                EXPORT CODEC_Handler              [WEAK]
				EXPORT AES_CCM_Handler            [WEAK]	
				EXPORT ADC12B_Handler             [WEAK]
				EXPORT RCADC_Handler              [WEAK]									
				EXPORT USB_Handler                [WEAK]
				EXPORT SLEEPTIMER_Handler         [WEAK]                
                EXPORT EXT_Handler                [WEAK]

UART0_Handler
SLEEPTIMER0_Handler
RADIO_Handler
PORT0_COMB_Handler
TIMER0_Handler
TIMER1_Handler
DUALTIMER_Handler
CHARGE_Handler
UART1_Handler
SPI_Handler
I2C_Handler
RTC_Handler
CODEC_Handler
AES_CCM_Handler
ADC12B_Handler
RCADC_Handler
USB_Handler
SLEEPTIMER_Handler
EXT_Handler

                B       .
                ENDP


                ALIGN


; User Initial Stack & Heap

                IF      :DEF:__MICROLIB

                EXPORT  __initial_sp
                EXPORT  __heap_base
                EXPORT  __heap_limit

                ELSE

                IMPORT  __use_two_region_memory
                EXPORT  __user_initial_stackheap

__user_initial_stackheap PROC
                LDR     R0, =  Heap_Mem
                LDR     R1, =(Stack_Mem + Stack_Size)
                LDR     R2, = (Heap_Mem +  Heap_Size)
                LDR     R3, = Stack_Mem
                BX      LR
                ENDP

                ALIGN

                ENDIF


                END
